(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[    131663,       4391]*)

(*NotebookOutlinePosition[    132614,       4423]*)

(*  CellTagsIndexPosition[    132570,       4419]*)

(*WindowFrame->Normal*)







Notebook[{

Cell[TextData[StyleBox["Example # 4 : Uniformly Magnetized Polyhedron ",

  FontSize->24]], "Title",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["Version : 0.1", "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["Introduction", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "This example illustrates the use of a polyhedron shape by means of the \"",

    

    Evaluatable->False,

    AspectRatioFixed->True],

  "radObjMltExtPgn",

  StyleBox[

  "\" function. A uniformly magnetized polyhedron is created with a \

magnetization of 1 Tesla. The field produced by this polyhedron is computed \

and shown to be uniform inside the volume of the polyhedron and equal to 2/3 \

Tesla as expected from an analytical integration.\nIt is assumed that the \

reader has some experience with ",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["Mathematica ",

    Evaluatable->False,

    AspectRatioFixed->True,

    FontSlant->"Italic"],

  StyleBox["and that he has successfully run Example#1.",

    Evaluatable->False,

    AspectRatioFixed->True],

  "\n",

  StyleBox[

  "Evaluate sections in the order of presentation: \"Load and Initialize \

Radia\" followed by \"Build the Geometry\", \"",

    Evaluatable->False,

    AspectRatioFixed->True],

  "Display the Geometry with QuickDraw 3D",

  StyleBox["\", \"Plot the Geometry\", \"Plot the Magnetic Field\".",

    Evaluatable->False,

    AspectRatioFixed->True],

  "\n",

  StyleBox[

  "If successful, try to modify some parameters (see the Reference Guide for \

the explanations on the ",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["Radia",

    Evaluatable->False,

    AspectRatioFixed->True,

    FontSlant->"Italic"],

  StyleBox[

  " functions) and re-execute the corresponding section. All sections must be \

evaluated in the order of presentation. A section may be evaluated several \

times with the same or different parameters if the previous sections have \

been evaluated before. The only limitation is memory. The Radia.exe memory   \

can be re-initialized by re-executing the section entitled \"Load and \

Initialize Radia\". The Kernel memory can be re-initialized by calling Exit[] \

and then re-executing all sections of this example. If the Front-End is \

running out of memory, close some windows or close the Front-End and start it \

again. Note that if by mistake any section is executed before the previous \

ones are executed, it may be necessary to exit the Kernel and re-start \

everything from the very beginning.",

    Evaluatable->False,

    AspectRatioFixed->True]

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Load and Initialize Radia"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The following instruction loads the Radia package and returns the Radia \

version number.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["<<Radia`;", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Build the Geometry", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"These instructions define a uniformly magnetized convex polyhedron which \

converges to a sphere at large values of segmentation parameters.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[

"SphericalVolume[R_, nn\[CurlyPhi]_, nz_, {mx_,my_,mz_}]:=Module[{z, dz, \

\[Theta], cos\[Theta], \[CurlyPhi], d\[CurlyPhi], SlicePgn, AllSlicePgns},\n\t\

dz=2.*R/nz;\tz=-R+dz; d\[CurlyPhi]=2.*\[Pi]/nn\[CurlyPhi];\n\t\

AllSlicePgns={{{{0.,0.}}, -R}};\n\tFor[i=1, i<=(nz-1), i++,\n\t\t\

\[Theta]=ArcSin[z/R]; cos\[Theta]=Cos[\[Theta]]; \[CurlyPhi]=d\[CurlyPhi];\n\t\

\tSlicePgn={{R*cos\[Theta], 0.}};\n\t\tFor[k=1, k<=(nn\[CurlyPhi]-1), k++,\n\t\

\t\tSlicePgn=Append[SlicePgn, {R*Cos[\[CurlyPhi]]*cos\[Theta], R*Sin[\

\[CurlyPhi]]*cos\[Theta]}]; \n\t\t\t\[CurlyPhi]+=d\[CurlyPhi];\n\t\t];\n \t\t\

AllSlicePgns=Append[AllSlicePgns, {SlicePgn, z}];\n\t\tz+=dz;\n\t];\n\t\

AllSlicePgns=Append[AllSlicePgns, {{{0.,0.}}, R}];\n\t\

radObjMltExtPgn[AllSlicePgns, N[{mx,my,mz}]]\n];\n\nradUtiDelAll[];\naSphere \

= SphericalVolume[1., 15, 15, {1.,0.,0.}];\nradObjDrwAtr[aSphere, \

{0,0.5,0.8}];"], "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Display the Geometry with QuickDraw 3D", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "If you have QuickDraw 3D installed on your platform (freely available for  \

PC and Macs from  Apple at \"",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["http://www.apple.com/quicktime/qd3d/\" ",

    FontFamily->"Monaco",

    FontSize->9],

  StyleBox[

  ") , execute the following line to display the geometry in a dedicated  \

window where you will be able to zoom, rotate etc....When you have finished,  \

Quit from the Menu File of Radia.exe (for Macs) or Exit from the Menu File of \

the Viewer window (for PC) to release the  memory required by QuickDraw3D and \

continue  executing the following instructions. ",

    Evaluatable->False,

    AspectRatioFixed->True]

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["radObjDrwQD3D[aSphere];", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Plot the Geometry"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"These instructions plot the geometry of coils previously created.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["\<\

RadPlot3DOptions[];

dr=radObjDrw[aSphere];



(* Draw the Geometry *)

Show[Graphics3D[dr

,PlotLabel->FontForm[\"Sphere\",{\"Times\",14}]

,DefaultFont -> {\"Times\",10}]];\

\>", "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics3D

/Times findfont 10  scalefont  setfont

% Scaling calculations

0 1 0 1 [

[.5 1.0125 -22 0 ]

[.5 1.0125 22 15 ]

[.5992 .87374 -7.88594 0 ]

[.5992 .87374 8.11406 15 ]

[.66707 .85032 -11.7109 0 ]

[.66707 .85032 12.2891 15 ]

[.74097 .82483 -4.34306 0 ]

[.74097 .82483 4.65694 15 ]

[.82174 .79696 -8.10258 0 ]

[.82174 .79696 8.89742 15 ]

[.91039 .76638 -4.23043 0 ]

[.91039 .76638 4.76957 15 ]

[.74485 .88671 -6.75414 0 ]

[.74485 .88671 7.24586 15 ]

[.39297 .04207 -7.86024 -15 ]

[.39297 .04207 8.13976 0 ]

[.5235 .07998 -12.0457 -15 ]

[.5235 .07998 11.9543 0 ]

[.64693 .11583 -4.60664 -15 ]

[.64693 .11583 4.39336 0 ]

[.76384 .14979 -8.85973 -15 ]

[.76384 .14979 8.14027 0 ]

[.87472 .182 -4.76909 -15 ]

[.87472 .182 4.23091 0 ]

[.64545 .05335 -7.16589 -15 ]

[.64545 .05335 6.83411 0 ]

[.89728 .21269 0 -5.34746 ]

[.89728 .21269 16 9.65254 ]

[.90497 .3364 0 -5.56598 ]

[.90497 .3364 24 9.43402 ]

[.91295 .46507 0 -5.79414 ]

[.91295 .46507 9 9.20586 ]

[.92125 .59901 0 -6.03258 ]

[.92125 .59901 17 8.96742 ]

[.92989 .73855 0 -6.28201 ]

[.92989 .73855 9 8.71799 ]

[.97389 .47893 0 -5.79414 ]

[.97389 .47893 13 9.20586 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

gsave

.5 1.0125 -83 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.687500 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 14.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.687500 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 14.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Sphere) show

102.125000 14.687500 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 14.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.59574 .86237 m

.91842 .75086 L

s

.25 Mabswid

.59903 .86124 m

.59894 .85499 L

s

gsave

.5992 .87374 -68.8859 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.66677 .83783 m

.66662 .83158 L

s

gsave

.66707 .85032 -72.7109 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.74054 .81234 m

.74032 .80609 L

s

gsave

.74097 .82483 -65.3431 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.82116 .78448 m

.82086 .77823 L

s

gsave

.82174 .79696 -69.1026 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.90964 .7539 m

.90927 .74766 L

s

gsave

.91039 .76638 -65.2304 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.61213 .85671 m

.61207 .85296 L

s

.62545 .85211 m

.62538 .84836 L

s

.63899 .84743 m

.63892 .84368 L

s

.65277 .84267 m

.65268 .83892 L

s

.68102 .8329 m

.68092 .82915 L

s

.69551 .82789 m

.69541 .82415 L

s

.71026 .8228 m

.71014 .81905 L

s

.72526 .81761 m

.72514 .81387 L

s

.75608 .80696 m

.75594 .80322 L

s

.77191 .80149 m

.77176 .79775 L

s

.78803 .79592 m

.78787 .79218 L

s

.80444 .79025 m

.80427 .78651 L

s

.83819 .77859 m

.838 .77484 L

s

.85554 .77259 m

.85535 .76885 L

s

.87323 .76648 m

.87303 .76274 L

s

.89126 .76025 m

.89104 .75651 L

s

gsave

.74485 .88671 -67.7541 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

72.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.38144 .05129 m

.88453 .19711 L

s

.25 Mabswid

.39275 .05457 m

.39264 .06081 L

s

gsave

.39297 .04207 -68.8602 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.52355 .09248 m

.52357 .09873 L

s

gsave

.5235 .07998 -73.0457 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.64723 .12833 m

.64738 .13457 L

s

gsave

.64693 .11583 -65.6066 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.76437 .16228 m

.76463 .16852 L

s

gsave

.76384 .14979 -69.8597 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.87547 .19448 m

.87584 .20072 L

s

gsave

.87472 .182 -65.7691 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.41951 .06232 m

.41946 .06607 L

s

.44596 .06999 m

.44593 .07374 L

s

.47212 .07757 m

.4721 .08132 L

s

.49798 .08506 m

.49797 .08881 L

s

.54883 .09981 m

.54886 .10355 L

s

.57384 .10705 m

.57388 .1108 L

s

.59857 .11422 m

.59863 .11797 L

s

.62303 .12131 m

.62311 .12506 L

s

.67116 .13526 m

.67127 .13901 L

s

.69484 .14213 m

.69496 .14587 L

s

.71827 .14892 m

.7184 .15266 L

s

.74144 .15563 m

.74158 .15938 L

s

.78706 .16885 m

.78723 .1726 L

s

.80951 .17536 m

.80969 .17911 L

s

.83172 .1818 m

.83192 .18555 L

s

.85371 .18817 m

.85392 .19192 L

s

gsave

.64545 .05335 -68.1659 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Y) show

72.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.88453 .19711 m

.91842 .75086 L

s

.25 Mabswid

.88527 .20925 m

.87926 .20752 L

s

gsave

.89728 .21269 -61 -9.34746 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.89286 .33328 m

.88681 .33172 L

s

gsave

.90497 .3364 -61 -9.56598 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.90076 .4623 m

.89467 .46091 L

s

gsave

.91295 .46507 -61 -9.79414 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.90898 .59661 m

.90285 .59541 L

s

gsave

.92125 .59901 -61 -10.0326 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.91755 .73655 m

.91138 .73554 L

s

gsave

.92989 .73855 -61 -10.282 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.88676 .23367 m

.88315 .23265 L

s

.88827 .25828 m

.88466 .25728 L

s

.88979 .28308 m

.88617 .28211 L

s

.89132 .30808 m

.88769 .30713 L

s

.89442 .35867 m

.89078 .35776 L

s

.89598 .38427 m

.89234 .38337 L

s

.89756 .41007 m

.89392 .4092 L

s

.89915 .43608 m

.8955 .43523 L

s

.90238 .48872 m

.89872 .48791 L

s

.90401 .51537 m

.90034 .51458 L

s

.90565 .54223 m

.90198 .54146 L

s

.90731 .56931 m

.90363 .56856 L

s

.91067 .62413 m

.90698 .62344 L

s

.91237 .65189 m

.90868 .65121 L

s

.91408 .67987 m

.91039 .67922 L

s

.91581 .70809 m

.91211 .70746 L

s

gsave

.97389 .47893 -61 -9.79414 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

71.500000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.001 w

[ .01 .01 ] 0 setdash

.14375 .28641 m

.11484 .80339 L

s

.11484 .80339 m

.59574 .86237 L

s

.59574 .86237 m

.58921 .38807 L

s

.58921 .38807 m

.14375 .28641 L

s

.38144 .05129 m

.88453 .19711 L

s

.88453 .19711 m

.91842 .75086 L

s

.91842 .75086 m

.36961 .66361 L

s

.36961 .66361 m

.38144 .05129 L

s

.14375 .28641 m

.11484 .80339 L

s

.11484 .80339 m

.36961 .66361 L

s

.36961 .66361 m

.38144 .05129 L

s

.38144 .05129 m

.14375 .28641 L

s

.58921 .38807 m

.88453 .19711 L

s

.88453 .19711 m

.91842 .75086 L

s

.91842 .75086 m

.59574 .86237 L

s

.59574 .86237 m

.58921 .38807 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

[ ] 0 setdash

.52477 .53801 m .52376 .50433 L .42827 .50099 L p 0 .339 .635 r

F P

0 g

s

.52376 .50433 m .52477 .53801 L .62079 .52746 L p 0 .314 .635 r

F P

0 g

s

.62079 .52746 m .61598 .4938 L .52376 .50433 L p 0 .314 .635 r

F P

0 g

s

.43259 .4656 m .42827 .50099 L .52376 .50433 L p 0 .347 .652 r

F P

0 g

s

.52376 .50433 m .52222 .46886 L .43259 .4656 L p 0 .347 .652 r

F P

0 g

s

.52222 .46886 m .52376 .50433 L .61598 .4938 L p 0 .324 .652 r

F P

0 g

s

.61598 .4938 m .60873 .4586 L .52222 .46886 L p 0 .324 .652 r

F P

0 g

s

.43872 .42788 m .43259 .4656 L .52222 .46886 L p 0 .356 .669 r

F P

0 g

s

.52222 .46886 m .52004 .43095 L .43872 .42788 L p 0 .356 .669 r

F P

0 g

s

.52004 .43095 m .52222 .46886 L .60873 .4586 L p 0 .334 .671 r

F P

0 g

s

.52533 .57029 m .52477 .53801 L .4254 .53467 L p 0 .331 .618 r

F P

0 g

s

.42827 .50099 m .4254 .53467 L .52477 .53801 L p 0 .339 .635 r

F P

0 g

s

.52477 .53801 m .52533 .57029 L .62342 .55991 L p 0 .304 .618 r

F P

0 g

s

.62342 .55991 m .62079 .52746 L .52477 .53801 L p 0 .304 .618 r

F P

0 g

s

.4254 .53467 m .42827 .50099 L .34198 .48408 L p 0 .366 .636 r

F P

0 g

s

.35177 .44913 m .34198 .48408 L .42827 .50099 L p 0 .374 .654 r

F P

0 g

s

.42827 .50099 m .43259 .4656 L .35177 .44913 L p 0 .374 .654 r

F P

0 g

s

.4474 .38665 m .43872 .42788 L .52004 .43095 L p 0 .366 .689 r

F P

0 g

s

.52004 .43095 m .51694 .38939 L .4474 .38665 L p 0 .366 .689 r

F P

0 g

s

.51694 .38939 m .52004 .43095 L .59844 .42128 L p 0 .346 .691 r

F P

0 g

s

.60873 .4586 m .59844 .42128 L .52004 .43095 L p 0 .334 .671 r

F P

0 g

s

.4254 .53467 m .42383 .567 L .52533 .57029 L p 0 .331 .618 r

F P

0 g

s

.52544 .6014 m .52533 .57029 L .42383 .567 L p 0 .322 .6 r

F P

0 g

s

.52533 .57029 m .52544 .6014 L .62401 .59135 L p 0 .294 .599 r

F P

0 g

s

.62401 .59135 m .62342 .55991 L .52533 .57029 L p 0 .294 .599 r

F P

0 g

s

.36562 .41237 m .35177 .44913 L .43259 .4656 L p 0 .381 .673 r

F P

0 g

s

.43259 .4656 m .43872 .42788 L .36562 .41237 L p 0 .381 .673 r

F P

0 g

s

.42383 .567 m .4254 .53467 L .33549 .51771 L p 0 .358 .617 r

F P

0 g

s

.34198 .48408 m .33549 .51771 L .4254 .53467 L p 0 .366 .636 r

F P

0 g

s

.38515 .37287 m .36562 .41237 L .43872 .42788 L p 0 .39 .695 r

F P

0 g

s

.43872 .42788 m .4474 .38665 L .38515 .37287 L p 0 .39 .695 r

F P

0 g

s

.42347 .59821 m .42383 .567 L .33191 .55031 L p 0 .35 .597 r

F P

0 g

s

.42383 .567 m .42347 .59821 L .52544 .6014 L p 0 .322 .6 r

F P

0 g

s

.33549 .51771 m .33191 .55031 L .42383 .567 L p 0 .358 .617 r

F P

0 g

s

.52512 .63147 m .52544 .6014 L .42347 .59821 L p 0 .312 .58 r

F P

0 g

s

.52544 .6014 m .52512 .63147 L .62251 .62192 L p 0 .283 .578 r

F P

0 g

s

.62251 .62192 m .62401 .59135 L .52544 .6014 L p 0 .283 .578 r

F P

0 g

s

.59844 .42128 m .58388 .38078 L .51694 .38939 L p 0 .346 .691 r

F P

0 g

s

.51223 .34113 m .51694 .38939 L .58388 .38078 L p 0 .362 .717 r

F P

0 g

s

.46059 .339 m .4474 .38665 L .51694 .38939 L p 0 .378 .715 r

F P

0 g

s

.51694 .38939 m .51223 .34113 L .46059 .339 L p 0 .378 .715 r

F P

0 g

s

.61598 .4938 m .62079 .52746 L .70058 .50393 L p 0 .285 .637 r

F P

0 g

s

.70058 .50393 m .69244 .47036 L .61598 .4938 L p 0 .285 .637 r

F P

0 g

s

.60873 .4586 m .61598 .4938 L .69244 .47036 L p 0 .298 .657 r

F P

0 g

s

.59844 .42128 m .60873 .4586 L .68017 .43579 L p 0 .312 .678 r

F P

0 g

s

.69244 .47036 m .68017 .43579 L .60873 .4586 L p 0 .298 .657 r

F P

0 g

s

.33191 .55031 m .33111 .58206 L .42347 .59821 L p 0 .35 .597 r

F P

0 g

s

.42435 .62845 m .42347 .59821 L .33111 .58206 L p 0 .34 .574 r

F P

0 g

s

.42347 .59821 m .42435 .62845 L .52512 .63147 L p 0 .312 .58 r

F P

0 g

s

.62079 .52746 m .62342 .55991 L .70507 .53673 L p 0 .271 .615 r

F P

0 g

s

.70507 .53673 m .70058 .50393 L .62079 .52746 L p 0 .271 .615 r

F P

0 g

s

.41467 .32832 m .38515 .37287 L .4474 .38665 L p 0 .4 .721 r

F P

0 g

s

.4474 .38665 m .46059 .339 L .41467 .32832 L p 0 .4 .721 r

F P

0 g

s

.68017 .43579 m .66283 .39985 L .59844 .42128 L p 0 .312 .678 r

F P

0 g

s

.58388 .38078 m .59844 .42128 L .66283 .39985 L p 0 .328 .701 r

F P

0 g

s

.52432 .66059 m .52512 .63147 L .42435 .62845 L p 0 .301 .557 r

F P

0 g

s

.52512 .63147 m .52432 .66059 L .61876 .65166 L p 0 .269 .554 r

F P

0 g

s

.61876 .65166 m .62251 .62192 L .52512 .63147 L p 0 .269 .554 r

F P

0 g

s

.62342 .55991 m .62401 .59135 L .70607 .56892 L p 0 .256 .592 r

F P

0 g

s

.70607 .56892 m .70507 .53673 L .62342 .55991 L p 0 .256 .592 r

F P

0 g

s

.58388 .38078 m .56182 .33444 L .51223 .34113 L p 0 .362 .717 r

F P

0 g

s

.66283 .39985 m .63845 .36178 L .58388 .38078 L p 0 .328 .701 r

F P

0 g

s

.56182 .33444 m .58388 .38078 L .63845 .36178 L p 0 .348 .729 r

F P

0 g

s

.42656 .65776 m .42435 .62845 L .33311 .61308 L p 0 .328 .548 r

F P

0 g

s

.42435 .62845 m .42656 .65776 L .52432 .66059 L p 0 .301 .557 r

F P

0 g

s

.33111 .58206 m .33311 .61308 L .42435 .62845 L p 0 .34 .574 r

F P

0 g

s

.62401 .59135 m .62251 .62192 L .70353 .60059 L p 0 .24 .566 r

F P

0 g

s

.70353 .60059 m .70607 .56892 L .62401 .59135 L p 0 .24 .566 r

F P

0 g

s

.34198 .48408 m .35177 .44913 L .29162 .4211 L p 0 .411 .661 r

F P

0 g

s

.31166 .38608 m .29162 .4211 L .35177 .44913 L p 0 .417 .685 r

F P

0 g

s

.35177 .44913 m .36562 .41237 L .31166 .38608 L p 0 .417 .685 r

F P

0 g

s

.29162 .4211 m .2774 .45521 L .34198 .48408 L p 0 .411 .661 r

F P

0 g

s

.33549 .51771 m .34198 .48408 L .2774 .45521 L p 0 .403 .637 r

F P

0 g

s

.33973 .34965 m .31166 .38608 L .36562 .41237 L p 0 .424 .709 r

F P

0 g

s

.36562 .41237 m .38515 .37287 L .33973 .34965 L p 0 .424 .709 r

F P

0 g

s

.46059 .339 m .51223 .34113 L .49859 .25632 L closepath p 0 .407 .775 r

F P

0 g

s

.51223 .34113 m .56182 .33444 L .49859 .25632 L closepath p 0 .398 .777 r

F P

0 g

s

.52432 .66059 m .52297 .6887 L .61241 .68057 L p 0 .252 .523 r

F P

0 g

s

.61241 .68057 m .61876 .65166 L .52432 .66059 L p 0 .252 .523 r

F P

0 g

s

.52297 .6887 m .52432 .66059 L .42656 .65776 L p 0 .286 .528 r

F P

0 g

s

.2774 .45521 m .26793 .4887 L .33549 .51771 L p 0 .403 .637 r

F P

0 g

s

.33191 .55031 m .33549 .51771 L .26793 .4887 L p 0 .395 .612 r

F P

0 g

s

.41467 .32832 m .46059 .339 L .49859 .25632 L closepath p 0 .42 .781 r

F P

0 g

s

.38174 .31051 m .33973 .34965 L .38515 .37287 L p 0 .43 .738 r

F P

0 g

s

.38515 .37287 m .41467 .32832 L .38174 .31051 L p 0 .43 .738 r

F P

0 g

s

.43032 .68612 m .42656 .65776 L .33815 .64342 L p 0 .312 .514 r

F P

0 g

s

.42656 .65776 m .43032 .68612 L .52297 .6887 L p 0 .286 .528 r

F P

0 g

s

.33311 .61308 m .33815 .64342 L .42656 .65776 L p 0 .328 .548 r

F P

0 g

s

.62251 .62192 m .61876 .65166 L .69718 .63177 L p 0 .221 .534 r

F P

0 g

s

.69718 .63177 m .70353 .60059 L .62251 .62192 L p 0 .221 .534 r

F P

0 g

s

.33111 .58206 m .33191 .55031 L .26271 .52172 L p 0 .385 .584 r

F P

0 g

s

.26793 .4887 m .26271 .52172 L .33191 .55031 L p 0 .395 .612 r

F P

0 g

s

.63845 .36178 m .60178 .31979 L .56182 .33444 L p 0 .348 .729 r

F P

0 g

s

.56182 .33444 m .60178 .31979 L .49859 .25632 L closepath p 0 .392 .787 r

F P

0 g

s

.33311 .61308 m .33111 .58206 L .26154 .55439 L p 0 .373 .551 r

F P

0 g

s

.26271 .52172 m .26154 .55439 L .33111 .58206 L p 0 .385 .584 r

F P

0 g

s

.52297 .6887 m .52091 .71565 L .60278 .70848 L p 0 .229 .481 r

F P

0 g

s

.60278 .70848 m .61241 .68057 L .52297 .6887 L p 0 .229 .481 r

F P

0 g

s

.52091 .71565 m .52297 .6887 L .43032 .68612 L p 0 .266 .488 r

F P

0 g

s

.38174 .31051 m .41467 .32832 L .49859 .25632 L closepath p 0 .437 .794 r

F P

0 g

s

.63845 .36178 m .66283 .39985 L .70267 .36914 L p 0 .307 .722 r

F P

0 g

s

.66283 .39985 m .68017 .43579 L .72494 .40294 L p 0 .282 .694 r

F P

0 g

s

.72494 .40294 m .70267 .36914 L .66283 .39985 L p 0 .282 .694 r

F P

0 g

s

.61876 .65166 m .61241 .68057 L .68643 .66247 L p 0 .196 .493 r

F P

0 g

s

.68643 .66247 m .69718 .63177 L .61876 .65166 L p 0 .196 .493 r

F P

0 g

s

.68017 .43579 m .69244 .47036 L .74079 .43645 L p 0 .259 .665 r

F P

0 g

s

.74079 .43645 m .72494 .40294 L .68017 .43579 L p 0 .259 .665 r

F P

0 g

s

.69244 .47036 m .70058 .50393 L .75135 .4698 L p 0 .235 .635 r

F P

0 g

s

.75135 .4698 m .74079 .43645 L .69244 .47036 L p 0 .235 .635 r

F P

0 g

s

.60178 .31979 m .63845 .36178 L .6716 .33477 L p 0 .336 .753 r

F P

0 g

s

.70267 .36914 m .6716 .33477 L .63845 .36178 L p 0 .307 .722 r

F P

0 g

s

.33815 .64342 m .34668 .67306 L .43032 .68612 L p 0 .312 .514 r

F P

0 g

s

.43032 .68612 m .43603 .71337 L .52091 .71565 L p 0 .266 .488 r

F P

0 g

s

.43603 .71337 m .43032 .68612 L .34668 .67306 L p 0 .291 .466 r

F P

0 g

s

.33815 .64342 m .33311 .61308 L .26447 .58678 L p 0 .358 .51 r

F P

0 g

s

.26154 .55439 m .26447 .58678 L .33311 .61308 L p 0 .373 .551 r

F P

0 g

s

.70058 .50393 m .70507 .53673 L .75718 .50308 L p 0 .209 .601 r

F P

0 g

s

.75718 .50308 m .75135 .4698 L .70058 .50393 L p 0 .209 .601 r

F P

0 g

s

.6716 .33477 m .62539 .29921 L .60178 .31979 L p 0 .336 .753 r

F P

0 g

s

.60178 .31979 m .62539 .29921 L .49859 .25632 L closepath p 0 .392 .804 r

F P

0 g

s

.70507 .53673 m .70607 .56892 L .75848 .53635 L p 0 .18 .562 r

F P

0 g

s

.75848 .53635 m .75718 .50308 L .70507 .53673 L p 0 .18 .562 r

F P

0 g

s

.61241 .68057 m .60278 .70848 L .67018 .69257 L p 0 .162 .435 r

F P

0 g

s

.67018 .69257 m .68643 .66247 L .61241 .68057 L p 0 .162 .435 r

F P

0 g

s

.34668 .67306 m .33815 .64342 L .27182 .61891 L p 0 .337 .457 r

F P

0 g

s

.26447 .58678 m .27182 .61891 L .33815 .64342 L p 0 .358 .51 r

F P

0 g

s

.52091 .71565 m .51786 .74095 L .58848 .73499 L p 0 .193 .413 r

F P

0 g

s

.58848 .73499 m .60278 .70848 L .52091 .71565 L p 0 .193 .413 r

F P

0 g

s

.51786 .74095 m .52091 .71565 L .43603 .71337 L p 0 .234 .425 r

F P

0 g

s

.70607 .56892 m .70353 .60059 L .75518 .56964 L p 0 .147 .515 r

F P

0 g

s

.75518 .56964 m .75848 .53635 L .70607 .56892 L p 0 .147 .515 r

F P

0 g

s

.31166 .38608 m .33973 .34965 L .31946 .32008 L p 0 .477 .737 r

F P

0 g

s

.36779 .28812 m .31946 .32008 L .33973 .34965 L p 0 .474 .77 r

F P

0 g

s

.33973 .34965 m .38174 .31051 L .36779 .28812 L p 0 .474 .77 r

F P

0 g

s

.31946 .32008 m .28676 .35232 L .31166 .38608 L p 0 .477 .737 r

F P

0 g

s

.29162 .4211 m .31166 .38608 L .28676 .35232 L p 0 .477 .703 r

F P

0 g

s

.44454 .73905 m .43603 .71337 L .35963 .70187 L p 0 .255 .39 r

F P

0 g

s

.43603 .71337 m .44454 .73905 L .51786 .74095 L p 0 .234 .425 r

F P

0 g

s

.34668 .67306 m .35963 .70187 L .43603 .71337 L p 0 .291 .466 r

F P

0 g

s

.28676 .35232 m .26322 .38486 L .29162 .4211 L p 0 .477 .703 r

F P

0 g

s

.2774 .45521 m .29162 .4211 L .26322 .38486 L p 0 .474 .665 r

F P

0 g

s

.36779 .28812 m .38174 .31051 L .49859 .25632 L closepath p 0 .457 .815 r

F P

0 g

s

.26793 .4887 m .2774 .45521 L .24642 .41773 L p 0 .467 .623 r

F P

0 g

s

.26322 .38486 m .24642 .41773 L .2774 .45521 L p 0 .474 .665 r

F P

0 g

s

.70353 .60059 m .69718 .63177 L .74694 .60297 L p 0 .107 .454 r

F P

0 g

s

.74694 .60297 m .75518 .56964 L .70353 .60059 L p 0 .107 .454 r

F P

0 g

s

.27182 .61891 m .28426 .65079 L .34668 .67306 L p 0 .337 .457 r

F P

0 g

s

.35963 .70187 m .34668 .67306 L .28426 .65079 L p 0 .304 .38 r

F P

0 g

s

.26271 .52172 m .26793 .4887 L .23519 .45091 L p 0 .457 .572 r

F P

0 g

s

.24642 .41773 m .23519 .45091 L .26793 .4887 L p 0 .467 .623 r

F P

0 g

s

.60278 .70848 m .58848 .73499 L .64618 .72182 L p 0 .109 .34 r

F P

0 g

s

.64618 .72182 m .67018 .69257 L .60278 .70848 L p 0 .109 .34 r

F P

0 g

s

.26154 .55439 m .26271 .52172 L .22897 .48443 L p 0 .44 .509 r

F P

0 g

s

.23519 .45091 m .22897 .48443 L .26271 .52172 L p 0 .457 .572 r

F P

0 g

s

.69718 .63177 m .68643 .66247 L .73303 .63634 L p 0 .055 .373 r

F P

0 g

s

.73303 .63634 m .74694 .60297 L .69718 .63177 L p 0 .055 .373 r

F P

0 g

s

.62539 .29921 m .6716 .33477 L .67622 .30362 L p 0 .322 .791 r

F P

0 g

s

.67622 .30362 m .62778 .27581 L .62539 .29921 L p 0 .322 .791 r

F P

0 g

s

.62539 .29921 m .62778 .27581 L .49859 .25632 L closepath p 0 .396 .828 r

F P

0 g

s

.6716 .33477 m .70267 .36914 L .70923 .33338 L p 0 .268 .751 r

F P

0 g

s

.70923 .33338 m .67622 .30362 L .6716 .33477 L p 0 .268 .751 r

F P

0 g

s

.51303 .76314 m .51786 .74095 L .44454 .73905 L p 0 .168 .293 r

F P

0 g

s

.51786 .74095 m .51303 .76314 L .56591 .75882 L p 0 .119 .272 r

F P

0 g

s

.56591 .75882 m .58848 .73499 L .51786 .74095 L p 0 .119 .272 r

F P

0 g

s

.70267 .36914 m .72494 .40294 L .73308 .36443 L p 0 .211 .7 r

F P

0 g

s

.73308 .36443 m .70923 .33338 L .70267 .36914 L p 0 .211 .7 r

F P

0 g

s

.26447 .58678 m .26154 .55439 L .22758 .51828 L p 0 .416 .43 r

F P

0 g

s

.22897 .48443 m .22758 .51828 L .26154 .55439 L p 0 .44 .509 r

F P

0 g

s

.45799 .76177 m .44454 .73905 L .37881 .72951 L p 0 .178 .23 r

F P

0 g

s

.44454 .73905 m .45799 .76177 L .51303 .76314 L p 0 .168 .293 r

F P

0 g

s

.35963 .70187 m .37881 .72951 L .44454 .73905 L p 0 .255 .39 r

F P

0 g

s

.28426 .65079 m .30303 .68235 L .35963 .70187 L p 0 .304 .38 r

F P

0 g

s

.37881 .72951 m .35963 .70187 L .30303 .68235 L p 0 .248 .254 r

F P

0 g

s

.62778 .27581 m .60725 .2536 L .49859 .25632 L closepath p 0 .406 .854 r

F P

0 g

s

.37634 .26476 m .36779 .28812 L .49859 .25632 L closepath p 0 .477 .841 r

F P

0 g

s

.56637 .23683 m .51229 .22899 L .49859 .25632 L closepath p 0 .44 .877 r

F P

0 g

s

.51229 .22899 m .45549 .2318 L .49859 .25632 L closepath p 0 .463 .877 r

F P

0 g

s

.45549 .2318 m .40718 .24465 L .49859 .25632 L closepath p 0 .484 .876 r

F P

0 g

s

.40718 .24465 m .37634 .26476 L .49859 .25632 L closepath p 0 .489 .865 r

F P

0 g

s

.60725 .2536 m .56637 .23683 L .49859 .25632 L closepath p 0 .42 .873 r

F P

0 g

s

.72494 .40294 m .74079 .43645 L .75018 .39651 L p 0 .148 .635 r

F P

0 g

s

.75018 .39651 m .73308 .36443 L .72494 .40294 L p 0 .148 .635 r

F P

0 g

s

.68643 .66247 m .67018 .69257 L .71211 .66973 L p 0 .05 .253 r

F P

0 g

s

.71211 .66973 m .73303 .63634 L .68643 .66247 L p 0 .05 .253 r

F P

0 g

s

.27182 .61891 m .26447 .58678 L .23107 .55248 L p 0 .378 .326 r

F P

0 g

s

.22758 .51828 m .23107 .55248 L .26447 .58678 L p 0 .416 .43 r

F P

0 g

s

.31946 .32008 m .36779 .28812 L .37634 .26476 L p 0 .531 .805 r

F P

0 g

s

.74079 .43645 m .75135 .4698 L .76162 .42947 L p 0 .077 .552 r

F P

0 g

s

.76162 .42947 m .75018 .39651 L .74079 .43645 L p 0 .077 .552 r

F P

0 g

s

.58848 .73499 m .56591 .75882 L .60861 .74935 L p 0 .05 .143 r

F P

0 g

s

.60861 .74935 m .64618 .72182 L .58848 .73499 L p 0 .05 .143 r

F P

0 g

s

.28676 .35232 m .31946 .32008 L .32988 .28875 L p 0 .548 .737 r

F P

0 g

s

.37634 .26476 m .32988 .28875 L .31946 .32008 L p 0 .531 .805 r

F P

0 g

s

.75135 .4698 m .75718 .50308 L .76795 .46323 L p 0 .05 .444 r

F P

0 g

s

.76795 .46323 m .76162 .42947 L .75135 .4698 L p 0 .05 .444 r

F P

0 g

s

.23107 .55248 m .23981 .58703 L .27182 .61891 L p 0 .378 .326 r

F P

0 g

s

.28426 .65079 m .27182 .61891 L .23981 .58703 L p 0 .321 .188 r

F P

0 g

s

.67018 .69257 m .64618 .72182 L .68144 .70305 L p 0 .05 .08 r

F P

0 g

s

.68144 .70305 m .71211 .66973 L .67018 .69257 L p 0 .05 .08 r

F P

0 g

s

.30303 .68235 m .33067 .7134 L .37881 .72951 L p 0 .248 .254 r

F P

0 g

s

.40899 .75487 m .37881 .72951 L .33067 .7134 L p 0 .126 .08 r

F P

0 g

s

.37881 .72951 m .40899 .75487 L .45799 .76177 L p 0 .178 .23 r

F P

0 g

s

.75718 .50308 m .75848 .53635 L .76937 .49776 L p 0 .05 .31 r

F P

0 g

s

.76937 .49776 m .76795 .46323 L .75718 .50308 L p 0 .05 .31 r

F P

0 g

s

.32988 .28875 m .29803 .31618 L .28676 .35232 L p 0 .548 .737 r

F P

0 g

s

.26322 .38486 m .28676 .35232 L .29803 .31618 L p 0 .54 .63 r

F P

0 g

s

.62778 .27581 m .67622 .30362 L .6491 .27362 L p 0 .279 .788 r

F P

0 g

s

.6491 .27362 m .60725 .2536 L .62778 .27581 L p 0 .279 .788 r

F P

0 g

s

.30303 .68235 m .28426 .65079 L .25455 .62193 L p 0 .232 .08 r

F P

0 g

s

.23981 .58703 m .25455 .62193 L .28426 .65079 L p 0 .321 .188 r

F P

0 g

s

.75848 .53635 m .75518 .56964 L .76578 .533 L p 0 .05 .15 r

F P

0 g

s

.76578 .533 m .76937 .49776 L .75848 .53635 L p 0 .05 .15 r

F P

0 g

s

.29803 .31618 m .27489 .3458 L .26322 .38486 L p 0 .54 .63 r

F P

0 g

s

.24642 .41773 m .26322 .38486 L .27489 .3458 L p 0 .503 .48 r

F P

0 g

s

.49848 .7651 m .56591 .75882 L .51303 .76314 L closepath p 0 .05 .08 r

F P

0 g

s

.49848 .7651 m .51303 .76314 L .45799 .76177 L closepath p 0 .05 .08 r

F P

0 g

s

.49848 .7651 m .45799 .76177 L .40899 .75487 L closepath p 0 .316 .676 r

F P

0 g

s

.67622 .30362 m .70923 .33338 L .67796 .29858 L p 0 .123 .602 r

F P

0 g

s

.67796 .29858 m .6491 .27362 L .67622 .30362 L p 0 .123 .602 r

F P

0 g

s

.23519 .45091 m .24642 .41773 L .25827 .3771 L p 0 .434 .296 r

F P

0 g

s

.27489 .3458 m .25827 .3771 L .24642 .41773 L p 0 .503 .48 r

F P

0 g

s

.75518 .56964 m .74694 .60297 L .75683 .56896 L p 0 .05 .08 r

F P

0 g

s

.75683 .56896 m .76578 .533 L .75518 .56964 L p 0 .05 .08 r

F P

0 g

s

.64618 .72182 m .60861 .74935 L .63396 .73601 L p 0 .05 .08 r

F P

0 g

s

.63396 .73601 m .68144 .70305 L .64618 .72182 L p 0 .05 .08 r

F P

0 g

s

.32988 .28875 m .37634 .26476 L .40718 .24465 L p 0 .501 .696 r

F P

0 g

s

.49848 .7651 m .60861 .74935 L .56591 .75882 L closepath p 0 .437 .738 r

F P

0 g

s

.25455 .62193 m .27666 .6572 L .30303 .68235 L p 0 .232 .08 r

F P

0 g

s

.33067 .7134 m .30303 .68235 L .27666 .6572 L p 0 .102 .08 r

F P

0 g

s

.25827 .3771 m .24711 .40982 L .23519 .45091 L p 0 .434 .296 r

F P

0 g

s

.22897 .48443 m .23519 .45091 L .24711 .40982 L p 0 .05 .08 r

F P

0 g

s

.74694 .60297 m .73303 .63634 L .7418 .60563 L p 0 .463 .369 r

F P

0 g

s

.7418 .60563 m .75683 .56896 L .74694 .60297 L p 0 .463 .369 r

F P

0 g

s

.70923 .33338 m .73308 .36443 L .69901 .32666 L p 0 .141 .08 r

F P

0 g

s

.69901 .32666 m .67796 .29858 L .70923 .33338 L p 0 .141 .08 r

F P

0 g

s

.33067 .7134 m .37374 .74334 L .40899 .75487 L p 0 .126 .08 r

F P

0 g

s

.49848 .7651 m .40899 .75487 L .37374 .74334 L closepath p 0 .355 .793 r

F P

0 g

s

.24711 .40982 m .24091 .4438 L .22897 .48443 L p 0 .05 .08 r

F P

0 g

s

.22758 .51828 m .22897 .48443 L .24091 .4438 L p 0 .05 .234 r

F P

0 g

s

.60725 .2536 m .6491 .27362 L .593 .25066 L p 0 .05 .08 r

F P

0 g

s

.593 .25066 m .56637 .23683 L .60725 .2536 L p 0 .05 .08 r

F P

0 g

s

.27666 .6572 m .30896 .69282 L .33067 .7134 L p 0 .102 .08 r

F P

0 g

s

.37374 .74334 m .33067 .7134 L .30896 .69282 L p 0 .169 .643 r

F P

0 g

s

.73303 .63634 m .71211 .66973 L .71932 .64306 L p 0 .517 .533 r

F P

0 g

s

.71932 .64306 m .7418 .60563 L .73303 .63634 L p 0 .517 .533 r

F P

0 g

s

.40718 .24465 m .37158 .26139 L .32988 .28875 L p 0 .501 .696 r

F P

0 g

s

.29803 .31618 m .32988 .28875 L .37158 .26139 L p 0 .05 .08 r

F P

0 g

s

.73308 .36443 m .75018 .39651 L .71419 .35712 L p 0 .265 .08 r

F P

0 g

s

.71419 .35712 m .69901 .32666 L .73308 .36443 L p 0 .265 .08 r

F P

0 g

s

.23107 .55248 m .22758 .51828 L .23952 .47892 L p 0 .05 .382 r

F P

0 g

s

.24091 .4438 m .23952 .47892 L .22758 .51828 L p 0 .05 .234 r

F P

0 g

s

.49848 .7651 m .63396 .73601 L .60861 .74935 L closepath p 0 .499 .837 r

F P

0 g

s

.37158 .26139 m .40718 .24465 L .45549 .2318 L p 0 .05 .08 r

F P

0 g

s

.71211 .66973 m .68144 .70305 L .68664 .68135 L p 0 .545 .669 r

F P

0 g

s

.68664 .68135 m .71932 .64306 L .71211 .66973 L p 0 .545 .669 r

F P

0 g

s

.23952 .47892 m .243 .51514 L .23107 .55248 L p 0 .05 .382 r

F P

0 g

s

.23981 .58703 m .23107 .55248 L .243 .51514 L p 0 .05 .502 r

F P

0 g

s

.75018 .39651 m .76162 .42947 L .72439 .38956 L p 0 .345 .248 r

F P

0 g

s

.72439 .38956 m .71419 .35712 L .75018 .39651 L p 0 .345 .248 r

F P

0 g

s

.37158 .26139 m .3469 .2843 L .29803 .31618 L p 0 .05 .08 r

F P

0 g

s

.27489 .3458 m .29803 .31618 L .3469 .2843 L p 0 .05 .117 r

F P

0 g

s

.56637 .23683 m .593 .25066 L .51772 .23983 L p 0 .05 .08 r

F P

0 g

s

.51772 .23983 m .51229 .22899 L .56637 .23683 L p 0 .05 .08 r

F P

0 g

s

.30896 .69282 m .35865 .72881 L .37374 .74334 L p 0 .169 .643 r

F P

0 g

s

.49848 .7651 m .37374 .74334 L .35865 .72881 L closepath p 0 .387 .858 r

F P

0 g

s

.243 .51514 m .25171 .55241 L .23981 .58703 L p 0 .05 .502 r

F P

0 g

s

.25455 .62193 m .23981 .58703 L .25171 .55241 L p 0 .113 .597 r

F P

0 g

s

.6491 .27362 m .67796 .29858 L .61154 .27171 L p 0 .162 .08 r

F P

0 g

s

.61154 .27171 m .593 .25066 L .6491 .27362 L p 0 .162 .08 r

F P

0 g

s

.76162 .42947 m .76795 .46323 L .73005 .42373 L p 0 .394 .379 r

F P

0 g

s

.73005 .42373 m .72439 .38956 L .76162 .42947 L p 0 .394 .379 r

F P

0 g

s

.68144 .70305 m .63396 .73601 L .63672 .7208 L p 0 .548 .775 r

F P

0 g

s

.63672 .7208 m .68664 .68135 L .68144 .70305 L p 0 .548 .775 r

F P

0 g

s

.45549 .2318 m .43844 .24373 L .37158 .26139 L p 0 .05 .08 r

F P

0 g

s

.43844 .24373 m .45549 .2318 L .51229 .22899 L p 0 .05 .08 r

F P

0 g

s

.25171 .55241 m .26632 .59074 L .25455 .62193 L p 0 .113 .597 r

F P

0 g

s

.27666 .6572 m .25455 .62193 L .26632 .59074 L p 0 .179 .673 r

F P

0 g

s

.51229 .22899 m .51772 .23983 L .43844 .24373 L p 0 .05 .08 r

F P

0 g

s

.25827 .3771 m .27489 .3458 L .32884 .31109 L p 0 .05 .296 r

F P

0 g

s

.3469 .2843 m .32884 .31109 L .27489 .3458 L p 0 .05 .117 r

F P

0 g

s

.76795 .46323 m .76937 .49776 L .73131 .45948 L p 0 .425 .474 r

F P

0 g

s

.73131 .45948 m .73005 .42373 L .76795 .46323 L p 0 .425 .474 r

F P

0 g

s

.30896 .69282 m .27666 .6572 L .28812 .6302 L p 0 .241 .737 r

F P

0 g

s

.26632 .59074 m .28812 .6302 L .27666 .6572 L p 0 .179 .673 r

F P

0 g

s

.49848 .7651 m .63672 .7208 L .63396 .73601 L closepath p 0 .506 .864 r

F P

0 g

s

.3469 .2843 m .37158 .26139 L .43844 .24373 L p 0 .05 .198 r

F P

0 g

s

.76937 .49776 m .76578 .533 L .7281 .49671 L p 0 .446 .546 r

F P

0 g

s

.7281 .49671 m .73131 .45948 L .76937 .49776 L p 0 .446 .546 r

F P

0 g

s

.67796 .29858 m .69901 .32666 L .62515 .29732 L p 0 .26 .29 r

F P

0 g

s

.62515 .29732 m .61154 .27171 L .67796 .29858 L p 0 .26 .29 r

F P

0 g

s

.24711 .40982 m .25827 .3771 L .31578 .34082 L p 0 .083 .408 r

F P

0 g

s

.32884 .31109 m .31578 .34082 L .25827 .3771 L p 0 .05 .296 r

F P

0 g

s

.28812 .6302 m .31968 .67096 L .30896 .69282 L p 0 .241 .737 r

F P

0 g

s

.35865 .72881 m .30896 .69282 L .31968 .67096 L p 0 .303 .793 r

F P

0 g

s

.76578 .533 m .75683 .56896 L .72011 .53536 L p 0 .461 .604 r

F P

0 g

s

.72011 .53536 m .7281 .49671 L .76578 .533 L p 0 .461 .604 r

F P

0 g

s

.593 .25066 m .61154 .27171 L .52151 .25898 L p 0 .184 .267 r

F P

0 g

s

.52151 .25898 m .51772 .23983 L .593 .25066 L p 0 .184 .267 r

F P

0 g

s

.24091 .4438 m .24711 .40982 L .30697 .373 L p 0 .133 .485 r

F P

0 g

s

.31578 .34082 m .30697 .373 L .24711 .40982 L p 0 .083 .408 r

F P

0 g

s

.49848 .7651 m .35865 .72881 L .3676 .71361 L closepath p 0 .399 .859 r

F P

0 g

s

.31968 .67096 m .3676 .71361 L .35865 .72881 L p 0 .303 .793 r

F P

0 g

s

.75683 .56896 m .7418 .60563 L .70673 .57543 L p 0 .472 .652 r

F P

0 g

s

.70673 .57543 m .72011 .53536 L .75683 .56896 L p 0 .472 .652 r

F P

0 g

s

.69901 .32666 m .71419 .35712 L .63501 .32637 L p 0 .308 .406 r

F P

0 g

s

.63501 .32637 m .62515 .29732 L .69901 .32666 L p 0 .308 .406 r

F P

0 g

s

.7418 .60563 m .71932 .64306 L .68684 .61702 L p 0 .48 .695 r

F P

0 g

s

.68684 .61702 m .70673 .57543 L .7418 .60563 L p 0 .48 .695 r

F P

0 g

s

.32884 .31109 m .3469 .2843 L .42654 .26356 L p 0 .13 .363 r

F P

0 g

s

.43844 .24373 m .42654 .26356 L .3469 .2843 L p 0 .05 .198 r

F P

0 g

s

.49848 .7651 m .51319 .69024 L .57118 .69537 L closepath p 0 .437 .817 r

F P

0 g

s

.49848 .7651 m .45224 .69209 L .51319 .69024 L closepath p 0 .421 .815 r

F P

0 g

s

.49848 .7651 m .40049 .70049 L .45224 .69209 L closepath p 0 .41 .822 r

F P

0 g

s

.49848 .7651 m .61491 .70633 L .63672 .7208 L closepath p 0 .484 .849 r

F P

0 g

s

.49848 .7651 m .57118 .69537 L .61491 .70633 L closepath p 0 .458 .829 r

F P

0 g

s

.49848 .7651 m .3676 .71361 L .40049 .70049 L closepath p 0 .404 .839 r

F P

0 g

s

.42654 .26356 m .43844 .24373 L .51772 .23983 L p 0 .145 .292 r

F P

0 g

s

.23952 .47892 m .24091 .4438 L .30207 .40731 L p 0 .172 .542 r

F P

0 g

s

.30697 .373 m .30207 .40731 L .24091 .4438 L p 0 .133 .485 r

F P

0 g

s

.71932 .64306 m .68664 .68135 L .65817 .66037 L p 0 .486 .737 r

F P

0 g

s

.65817 .66037 m .68684 .61702 L .71932 .64306 L p 0 .486 .737 r

F P

0 g

s

.51772 .23983 m .52151 .25898 L .42654 .26356 L p 0 .145 .292 r

F P

0 g

s

.68664 .68135 m .63672 .7208 L .61491 .70633 L p 0 .49 .781 r

F P

0 g

s

.61491 .70633 m .65817 .66037 L .68664 .68135 L p 0 .49 .781 r

F P

0 g

s

.243 .51514 m .23952 .47892 L .30097 .44357 L p 0 .204 .587 r

F P

0 g

s

.30207 .40731 m .30097 .44357 L .23952 .47892 L p 0 .172 .542 r

F P

0 g

s

.71419 .35712 m .72439 .38956 L .64167 .3583 L p 0 .337 .478 r

F P

0 g

s

.64167 .3583 m .63501 .32637 L .71419 .35712 L p 0 .337 .478 r

F P

0 g

s

.25171 .55241 m .243 .51514 L .30373 .48163 L p 0 .231 .625 r

F P

0 g

s

.30097 .44357 m .30373 .48163 L .243 .51514 L p 0 .204 .587 r

F P

0 g

s

.61154 .27171 m .62515 .29732 L .5243 .28335 L p 0 .249 .402 r

F P

0 g

s

.5243 .28335 m .52151 .25898 L .61154 .27171 L p 0 .249 .402 r

F P

0 g

s

.31578 .34082 m .32884 .31109 L .41778 .28838 L p 0 .181 .451 r

F P

0 g

s

.42654 .26356 m .41778 .28838 L .32884 .31109 L p 0 .13 .363 r

F P

0 g

s

.30373 .48163 m .3106 .52143 L .25171 .55241 L p 0 .231 .625 r

F P

0 g

s

.26632 .59074 m .25171 .55241 L .3106 .52143 L p 0 .256 .659 r

F P

0 g

s

.72439 .38956 m .73005 .42373 L .64536 .39273 L p 0 .357 .53 r

F P

0 g

s

.64536 .39273 m .64167 .3583 L .72439 .38956 L p 0 .357 .53 r

F P

0 g

s

.36368 .6518 m .40049 .70049 L .3676 .71361 L p 0 .338 .765 r

F P

0 g

s

.3676 .71361 m .31968 .67096 L .36368 .6518 L p 0 .338 .765 r

F P

0 g

s

.28812 .6302 m .26632 .59074 L .3221 .56296 L p 0 .281 .692 r

F P

0 g

s

.3106 .52143 m .3221 .56296 L .26632 .59074 L p 0 .256 .659 r

F P

0 g

s

.41778 .28838 m .42654 .26356 L .52151 .25898 L p 0 .21 .416 r

F P

0 g

s

.31968 .67096 m .28812 .6302 L .33916 .60631 L p 0 .307 .726 r

F P

0 g

s

.3221 .56296 m .33916 .60631 L .28812 .6302 L p 0 .281 .692 r

F P

0 g

s

.33916 .60631 m .36368 .6518 L .31968 .67096 L p 0 .307 .726 r

F P

0 g

s

.73005 .42373 m .73131 .45948 L .64619 .42944 L p 0 .372 .569 r

F P

0 g

s

.64619 .42944 m .64536 .39273 L .73005 .42373 L p 0 .372 .569 r

F P

0 g

s

.52151 .25898 m .5243 .28335 L .41778 .28838 L p 0 .21 .416 r

F P

0 g

s

.30697 .373 m .31578 .34082 L .41142 .31699 L p 0 .214 .507 r

F P

0 g

s

.41778 .28838 m .41142 .31699 L .31578 .34082 L p 0 .181 .451 r

F P

0 g

s

.62515 .29732 m .63501 .32637 L .52633 .31169 L p 0 .283 .475 r

F P

0 g

s

.52633 .31169 m .5243 .28335 L .62515 .29732 L p 0 .283 .475 r

F P

0 g

s

.73131 .45948 m .7281 .49671 L .64408 .46825 L p 0 .384 .602 r

F P

0 g

s

.64408 .46825 m .64619 .42944 L .73131 .45948 L p 0 .384 .602 r

F P

0 g

s

.65817 .66037 m .61491 .70633 L .57118 .69537 L p 0 .436 .751 r

F P

0 g

s

.41142 .31699 m .40712 .34874 L .30697 .373 L p 0 .214 .507 r

F P

0 g

s

.30207 .40731 m .30697 .373 L .40712 .34874 L p 0 .238 .548 r

F P

0 g

s

.7281 .49671 m .72011 .53536 L .63886 .50908 L p 0 .395 .631 r

F P

0 g

s

.63886 .50908 m .64408 .46825 L .7281 .49671 L p 0 .395 .631 r

F P

0 g

s

.41142 .31699 m .41778 .28838 L .5243 .28335 L p 0 .246 .484 r

F P

0 g

s

.57118 .69537 m .59878 .64427 L .65817 .66037 L p 0 .436 .751 r

F P

0 g

s

.68684 .61702 m .65817 .66037 L .59878 .64427 L p 0 .424 .715 r

F P

0 g

s

.72011 .53536 m .70673 .57543 L .63015 .55191 L p 0 .404 .658 r

F P

0 g

s

.63015 .55191 m .63886 .50908 L .72011 .53536 L p 0 .404 .658 r

F P

0 g

s

.43459 .6394 m .45224 .69209 L .40049 .70049 L p 0 .358 .742 r

F P

0 g

s

.40049 .70049 m .36368 .6518 L .43459 .6394 L p 0 .358 .742 r

F P

0 g

s

.63501 .32637 m .64167 .3583 L .5277 .34335 L p 0 .305 .522 r

F P

0 g

s

.5277 .34335 m .52633 .31169 L .63501 .32637 L p 0 .305 .522 r

F P

0 g

s

.70673 .57543 m .68684 .61702 L .61725 .59685 L p 0 .414 .685 r

F P

0 g

s

.59878 .64427 m .61725 .59685 L .68684 .61702 L p 0 .424 .715 r

F P

0 g

s

.61725 .59685 m .63015 .55191 L .70673 .57543 L p 0 .414 .685 r

F P

0 g

s

.5243 .28335 m .52633 .31169 L .41142 .31699 L p 0 .246 .484 r

F P

0 g

s

.30097 .44357 m .30207 .40731 L .40472 .38325 L p 0 .258 .58 r

F P

0 g

s

.40712 .34874 m .40472 .38325 L .30207 .40731 L p 0 .238 .548 r

F P

0 g

s

.59878 .64427 m .57118 .69537 L .51319 .69024 L p 0 .402 .736 r

F P

0 g

s

.30373 .48163 m .30097 .44357 L .40418 .42024 L p 0 .274 .607 r

F P

0 g

s

.40472 .38325 m .40418 .42024 L .30097 .44357 L p 0 .258 .58 r

F P

0 g

s

.40712 .34874 m .41142 .31699 L .52633 .31169 L p 0 .269 .528 r

F P

0 g

s

.42275 .59073 m .43459 .6394 L .36368 .6518 L p 0 .336 .707 r

F P

0 g

s

.36368 .6518 m .33916 .60631 L .42275 .59073 L p 0 .336 .707 r

F P

0 g

s

.64167 .3583 m .64536 .39273 L .52845 .37789 L p 0 .321 .557 r

F P

0 g

s

.52845 .37789 m .5277 .34335 L .64167 .3583 L p 0 .321 .557 r

F P

0 g

s

.51883 .63666 m .51319 .69024 L .45224 .69209 L p 0 .377 .733 r

F P

0 g

s

.45224 .69209 m .43459 .6394 L .51883 .63666 L p 0 .377 .733 r

F P

0 g

s

.3106 .52143 m .30373 .48163 L .40552 .45954 L p 0 .289 .632 r

F P

0 g

s

.40418 .42024 m .40552 .45954 L .30373 .48163 L p 0 .274 .607 r

F P

0 g

s

.52633 .31169 m .5277 .34335 L .40712 .34874 L p 0 .269 .528 r

F P

0 g

s

.41447 .54474 m .42275 .59073 L .33916 .60631 L p 0 .319 .68 r

F P

0 g

s

.33916 .60631 m .3221 .56296 L .41447 .54474 L p 0 .319 .68 r

F P

0 g

s

.51319 .69024 m .51883 .63666 L .59878 .64427 L p 0 .402 .736 r

F P

0 g

s

.40552 .45954 m .40887 .50105 L .3106 .52143 L p 0 .289 .632 r

F P

0 g

s

.3221 .56296 m .3106 .52143 L .40887 .50105 L p 0 .304 .656 r

F P

0 g

s

.40887 .50105 m .41447 .54474 L .3221 .56296 L p 0 .304 .656 r

F P

0 g

s

.64536 .39273 m .64619 .42944 L .52862 .41504 L p 0 .334 .586 r

F P

0 g

s

.52862 .41504 m .52845 .37789 L .64536 .39273 L p 0 .334 .586 r

F P

0 g

s

.40472 .38325 m .40712 .34874 L .5277 .34335 L p 0 .286 .561 r

F P

0 g

s

.61725 .59685 m .59878 .64427 L .51883 .63666 L p 0 .387 .702 r

F P

0 g

s

.64619 .42944 m .64408 .46825 L .52818 .45462 L p 0 .345 .61 r

F P

0 g

s

.52818 .45462 m .52862 .41504 L .64619 .42944 L p 0 .345 .61 r

F P

0 g

s

.5277 .34335 m .52845 .37789 L .40472 .38325 L p 0 .286 .561 r

F P

0 g

s

.63015 .55191 m .61725 .59685 L .52263 .58728 L p 0 .375 .676 r

F P

0 g

s

.51883 .63666 m .52263 .58728 L .61725 .59685 L p 0 .387 .702 r

F P

0 g

s

.52263 .58728 m .51883 .63666 L .43459 .6394 L p 0 .36 .7 r

F P

0 g

s

.43459 .6394 m .42275 .59073 L .52263 .58728 L p 0 .36 .7 r

F P

0 g

s

.40418 .42024 m .40472 .38325 L .52845 .37789 L p 0 .3 .588 r

F P

0 g

s

.64408 .46825 m .63886 .50908 L .52709 .49652 L p 0 .355 .632 r

F P

0 g

s

.52709 .49652 m .52818 .45462 L .64408 .46825 L p 0 .355 .632 r

F P

0 g

s

.63886 .50908 m .63015 .55191 L .52529 .5407 L p 0 .365 .654 r

F P

0 g

s

.52263 .58728 m .52529 .5407 L .63015 .55191 L p 0 .375 .676 r

F P

0 g

s

.52529 .5407 m .52709 .49652 L .63886 .50908 L p 0 .365 .654 r

F P

0 g

s

.52845 .37789 m .52862 .41504 L .40418 .42024 L p 0 .3 .588 r

F P

0 g

s

.40552 .45954 m .40418 .42024 L .52862 .41504 L p 0 .312 .611 r

F P

0 g

s

.52529 .5407 m .52263 .58728 L .42275 .59073 L p 0 .346 .675 r

F P

0 g

s

.42275 .59073 m .41447 .54474 L .52529 .5407 L p 0 .346 .675 r

F P

0 g

s

.52862 .41504 m .52818 .45462 L .40552 .45954 L p 0 .312 .611 r

F P

0 g

s

.40887 .50105 m .40552 .45954 L .52818 .45462 L p 0 .324 .632 r

F P

0 g

s

.52709 .49652 m .52529 .5407 L .41447 .54474 L p 0 .335 .653 r

F P

0 g

s

.41447 .54474 m .40887 .50105 L .52709 .49652 L p 0 .335 .653 r

F P

0 g

s

.52818 .45462 m .52709 .49652 L .40887 .50105 L p 0 .324 .632 r

F P

0 g

s

[ .01 .01 ] 0 setdash

.38144 .05129 m

.88453 .19711 L

s

.88453 .19711 m

.91842 .75086 L

s

.91842 .75086 m

.36961 .66361 L

s

.36961 .66361 m

.38144 .05129 L

s

.14375 .28641 m

.11484 .80339 L

s

.11484 .80339 m

.36961 .66361 L

s

.36961 .66361 m

.38144 .05129 L

s

.38144 .05129 m

.14375 .28641 L

s

.003 w

[ ] 0 setdash

.88453 .19711 m

.91842 .75086 L

s

.25 Mabswid

.88527 .20925 m

.87926 .20752 L

s

gsave

.89728 .21269 -61 -9.34746 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.89286 .33328 m

.88681 .33172 L

s

gsave

.90497 .3364 -61 -9.56598 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.90076 .4623 m

.89467 .46091 L

s

gsave

.91295 .46507 -61 -9.79414 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.90898 .59661 m

.90285 .59541 L

s

gsave

.92125 .59901 -61 -10.0326 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.91755 .73655 m

.91138 .73554 L

s

gsave

.92989 .73855 -61 -10.282 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.88676 .23367 m

.88315 .23265 L

s

.88827 .25828 m

.88466 .25728 L

s

.88979 .28308 m

.88617 .28211 L

s

.89132 .30808 m

.88769 .30713 L

s

.89442 .35867 m

.89078 .35776 L

s

.89598 .38427 m

.89234 .38337 L

s

.89756 .41007 m

.89392 .4092 L

s

.89915 .43608 m

.8955 .43523 L

s

.90238 .48872 m

.89872 .48791 L

s

.90401 .51537 m

.90034 .51458 L

s

.90565 .54223 m

.90198 .54146 L

s

.90731 .56931 m

.90363 .56856 L

s

.91067 .62413 m

.90698 .62344 L

s

.91237 .65189 m

.90868 .65121 L

s

.91408 .67987 m

.91039 .67922 L

s

.91581 .70809 m

.91211 .70746 L

s

gsave

.97389 .47893 -61 -9.79414 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

71.500000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{353, 353},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001HA000`40O003h00OogooHWoo003oOomR

Ool00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00S7oo0`00dWoo002=Ool00`00Oomoo`3A

Ool008Eoo`@000Aoo`03001oogoo0=5oo`00SGoo00<007ooOol0dGoo002=Ool00`00Oomoo`1:Ool3

0024Ool008eoo`03001oogoo04]oo`03001oogoo08=oo`00S7oo0P00CGoo00<007ooOol0Pgoo003J

Ool00`00Ool00024Ool00=Yoo`03001oo`0008Aoo`00fGoo00D007ooOomoo`0008=oo`00f7oo0`00

00Aoo`000000089oo`00ogooHWoo002cOol20003Ool4002UOol008Ioo`@002Qoo`04001oogoo0006

Ool00`00Oomoo`2ROol008Eoo`800003Ool0000000@001ioo`@0009oo`04001oogoo0006Ool00`00

Oomoo`2ROol008Aoo`03001oo`0000=oo`03001oo`0000<0029oo`04001oogoo0006Ool00`00Oomo

o`2ROol008Ioo`05001oogooOol00004Ool6000MOol01000Oomoo`0017oo0P00YGoo0021Ool00`00

Oomoo`02Ool00`00Oomoo`0:Ool4000KOol01000Oomoo`0017oo00<007ooOol0Y7oo0020Ool00`00

Oomoo`0COol5000HOol20006Ool2002TOol0081oo`03001oogoo01Moo`<00<Aoo`00Ogoo00<007oo

Ool017oo00<007ooOol04Woo00<007oo00000`00`7oo0026Ool00`00Oomoo`0HOol4002lOol007eo

o`03001oogoo00Ioo`03001oogoo01]oo`@00;Uoo`00Ngoo0P002Goo00<007ooOol06goo00@007oo

Oomoo`<00;Ioo`00NWoo00<007ooOol0;Woo1000;Goo0P00Pgoo002]Ool5000YOol01000Oomoo`00

PWoo002bOol5000TOol01000Oomoo`00PWoo001hOol00`00Oomoo`0;Ool00`00Oomoo`0/Ool6000P

Ool01000Oomoo`00PWoo001fOol2000>Ool00`00Oomoo`0/Ool01000Oomoogoo10007Woo00@007oo

Ool0089oo`00MGoo00<007ooOol03Woo00<007ooOol0<goo1@006Woo00@007ooOol0089oo`00QWoo

00<007ooOol0=Goo00<007oo00000P006Goo0P00Pgoo001cOol00`00Oomoo`1=Ool5002IOol0079o

o`03001oogoo055oo`@009Moo`00LWoo00<007ooOol04Goo00<007ooOol0@Goo1@00TWoo001aOol0

0`00Oomoo`0BOol00`00Oomoo`15Ool3002@Ool008Eoo`03001oogoo04Ioo`03001oogoo00@008ao

o`00KWoo00<007ooOol057oo00<007ooOol0C7oo10009goo0P000goo1000FGoo001]Ool00`00Oomo

o`0EOol00`00Oomoo`1>Ool00`00Ool00003000ROol01000Oomoo`001Woo00<007ooOol0EWoo001/

Ool00`00Oomoo`1/Ool6000MOol01000Oomoo`001Woo00<007ooOol0EWoo003NOol5000KOol01000

Oomoo`001Woo00<007ooOol0EWoo0025Ool00`00Oomoo`1FOol00`00Oomoo`02Ool5000FOol01000

Oomoo`0017oo0P00FGoo001ZOol00`00Oomoo`0HOol00`00Oomoo`1NOol4000DOol01000Oomoo`00

17oo00<007ooOol0F7oo001XOol2000KOol00`00Oomoo`1NOol01000Oomoogoo10004Goo0P001Woo

0P00F7oo001WOol00`00Oomoo`0KOol00`00Oomoo`1UOol4001`Ool00>ioo`03001oogoo00<006eo

o`00IGoo00<007ooOol0S7oo1000JGoo001TOol00`00Oomoo`2?Ool00`00Ool00002000]Ool3000f

Ool006Aoo`03001oogoo01ioo`03001oogoo07=oo`@002Yoo`03001oogoo03Eoo`00Hgoo00<007oo

Ool07goo00<007ooOol0MGoo00<007oo00000P009goo00<007ooOol0=Goo0025Ool00`00Oomoo`1i

Ool5000SOol00`00Oomoo`0eOol0061oo`03001oogoo029oo`03001oogoo07eoo`D001moo`03001o

ogoo03Eoo`00Ggoo00<007ooOol0Xgoo00@007ooOomoo`D001]oo`03001oogoo03Eoo`00GWoo00<0

07ooOol0Zgoo100067oo0P00=goo0025Ool00`00Oomoo`25Ool00`00Oomoo`04001=Ool008Eoo`03

001oogoo08]oo`@004Yoo`00G7oo00<007ooOol09Woo00<007ooOol0S7oo00<007ooOol01000AWoo

001JOol2000YOol00`00Oomoo`2BOol40013Ool005Uoo`03001oogoo02Uoo`03001oogoo09=oo`03

001oogoo00<0041oo`00ogoo8Woo1000?7oo001GOol00`00Oomoo`39Ool00`00Ool00002000iOol0

05Ioo`03001oogoo02aoo`03001oogoo09moo`D003Eoo`00EGoo00<007ooOol0;Goo00<007ooOol0

XWoo00@007oo000003=oo`00E7oo00<007ooOol0;Woo00<007ooOol0XWoo0P0000=oo`00Ool0<Woo

0025Ool00`00Oomoo`2ROol01000Oomoo`00<goo001BOol00`00Oomoo`3FOol00`00Ool0000cOol0

055oo`03001oogoo0==oo`03001oogoo009oo`8003=oo`00D7oo00<007ooOol0<Woo00<007ooOol0

WGoo0P001Woo00<007ooOol02goo0`008goo0025Ool00`00Oomoo`2LOol00`00Oomoo`06Ool00`00

Oomoo`0<Ool00`00Oomoo`0ROol008Eoo`03001oogoo09Uoo`03001oogoo00Uoo`03001oogoo00Ao

o`@000Aoo`03001oogoo029oo`00CGoo00<007ooOol0=Goo00<007ooOol0Ugoo0P0037oo00<007oo

Ool037oo00<007ooOol08Woo001<Ool00`00Oomoo`0fOol00`00Oomoo`2FOol00`00Oomoo`0<Ool2

000=Ool00`00Oomoo`0ROol004]oo`03001oogoo0=moo`8000eoo`03001oogoo029oo`00WWoo6000

IWoo00<007ooOol03goo00<007ooOol02Woo0P0097oo0019Ool00`00Oomoo`0iOol00`00Oomoo`0C

Ool4000C0280100002808P0R2@00Fgoo0P0047oo0`00<Woo0018Ool00`00Oomoo`0jOol00`00Oomo

o`0@Ool2000202800`0002808P0C02800`0002808P0:0286001DOol00`00Oomoo`0BOol00`00Oomo

o`0`Ool004Moo`03001oogoo03]oo`03001oogoo00aoo`<000<08P8000/08Q0000d08P<006Moo`03

001oogoo031oo`00AWoo00<007ooOol0?7oo00<007ooOol02Goo0`00100R3`00302900@0002X0:P0

Z0H000T08P<004aoo`8001Moo`03001oogoo031oo`00SWoo0`000`0R0`0000<09P0008T06@2900<0

002X0:P01`2X1P001@0R1000Agoo0P006Goo00<007ooOol0<7oo0014Ool00`00Oomoo`15Ool20002

0284000402H00`0008T0R@0H08T00`000:P0Z00=0:P600000`0R00000002001POol00`00Oomoo`0`

Ool004=oo`03001oogoo04Aoo`80000402800000000702H00`0008T0R@0J08T00`000:P0Z00B0:P7

0011Ool00`00Oomoo`0JOol00`00Oomoo`0`Ool0049oo`03001oogoo041oo`03001oo`0000D000X0

9P030000R@2901X0R@030000Z02X01H0Z0H003aoo`8001eoo`03001oogoo031oo`00QGoo10003@0V

00<0002908T050292P005`2X00<0002R0:801000>Goo00<007ooOol077oo0P00<Woo0023Ool3000@

02H00`0008T0R@0408T@00070<d00`000>`0k006000B0:P010000:80XP2R1000Egoo00<007ooOol0

<7oo000oOol00`00Oomoo`0oOol2000202H00`0002H09P0<02H9000G0<d00`000>`0k0060>`6000<

0:P00`000:80XP040:84000aOol00`00Oomoo`0POol00`00Oomoo`0`Ool003ioo`03001oogoo03mo

o`8000h09P<00080R`030000c@3=01`0c@030000k03/00`0k0H000L0Z0030000XP2R00H0XP<002eo

o`8002=oo`03001oogoo031oo`00?Goo00<007ooOol0?Woo00<0000R00002`0V1000102;00<0003=

0<d07@3=00<0003/0>`04P3/1P000P2X00<0002R0:801`2R0`00:Woo00<007ooOol08goo00<007oo

Ool0<7oo001mOol00`000280000502H0100002H09P0V0`00202;00<0003=0<d07P3=00<0003/0>`0

5`3/1@002P2R0P009Goo00<007ooOol09Woo00<007ooOol0<7oo000kOol00`00Oomoo`0mOol20000

0`0R00009P0502H4000:08/00`000<d0c@0O0<d00`000>`0k00K0>`3000:0:800`00Oomoo`0QOol0

0`00Oomoo`0WOol2000aOol003Yoo`03001oogoo03aoo`8000808P0400009P0V02H4000>08/00`00

0<d0c@0O0<d00`000>`0k00K0>`00`000@T12@0300080:800`00Oomoo`0OOol00`00Oomoo`0XOol2

000aOol003Uoo`03001oogoo03aoo`0400008P0R0285000308/00`0008/0R`0<08/00`000<d0c@0O

0<d00`000>`0k00L0>`00`000@T12@020@T200070:800`00Oomoo`18Ool3000aOol003Qoo`03001o

ogoo03]oo`8000<08P8000L0R`030000R`2;00/0R`030000c@3=00l0cAH001X0k00300012@4900@1

2@8000H0XP03001oogoo01Yoo`03001oogoo02aoo`03001oogoo02moo`00=goo00@007oo000003Yo

o`0400008P0R0282000F08/C000A0>l00`000Bl1;`020Bl8000C0>`00`000@T12@050@T300040:80

0`00Oomoo`0GOol2000_Ool00`00Oomoo`0_Ool003Moo`04001oogooOol3000fOol00`0002808P02

00000`0S0000R`0A08/400000`2^0000k`0Q0>l00`000Bl1;`0:0Bl9000;0>`00`000@T12@070@T2

00030:800`00Oomoo`0EOol00`00Oomoo`0_Ool00`00Oomoo`0_Ool003Moo`03001oogoo00Ioo`@0

02ioo`8000808P0400008`0S000:08/00`0008/0R`0208/400050:h00`000>l0k`0P0>l00`000Bl1

;`0C0Bl800030>`00`000@T12@090@T300000`2R001oo`17Ool00`00Oomoo`0_Ool003Moo`03001o

ogoo00aoo`8002Uoo`0300008P0R008000808`030000R`2;00T0R`030000R`00008000P0[P030000

k`3_0240k`030001;`4_01/1;`H000`12@<0019oo`03001oogoo039oo`03001oogoo02moo`00B7oo

0P009Woo00@0000R000000@08`030000R`2;00L0R`@000/0[P030000k`3_0280k`030001;`4_01h1

;`040001;000000<0@T2000?Ool2000eOol00`00Oomoo`0_Ool004eoo`@001ioo`<000D08`030000

R`2;00D0R`<00080[P030000[P2^00X0[P030000k`3_0280k`030001;`4_01l1;`030001;04/0080

00`12@03001oogoo00]oo`03001oogoo03Eoo`03001oogoo02moo`00=goo00<007ooOol06Goo0P00

6Goo0P001P0S00<0002;08/00P2;10004P2^00<0003_0>l08P3_00<0004_0Bl07`4_00<0004/0B`0

0P4/0`002P4900<007ooOol027oo00<007ooOol0=Woo0P00<Goo000gOol00`00Oomoo`0KOol20003

Ool2000@Ool3000702<5000F0:h00`000>l0k`0R0>l00`000Bl1;`0O0Bl00`000B`1;0050B`20008

0@T20007Ool2000jOol00`00Oomoo`0_Ool003Moo`03001oogoo029oo`8000eoo`8000P08`8001T0

[P030000k`3_01X0k`d001h1;`030001;04/00L1;0<000H12@8000Eoo`03001oogoo03Yoo`03001o

ogoo02moo`00=goo00<007ooOol09Woo0P0027oo00<0000S02<01P0S0P003`2^00<0002^0:h02@2^

00<0003_0>l01`3_4`002@4@00@0004`0C01<0L001P1;`030001;04/00T1;08000D12@80045oo`03

001oogoo02moo`00=goo00<007ooOol0:7oo0P000goo0`001`0S0P0000<0:@000:h03P2^00<0002^

0:h0202^2`00704@00<0004`0C00204`1`004@4_00<0004/0B`02`4/0P0010490`00?goo00<007oo

Ool0;goo001YOol00`0002<08`0402<0100002T0:@00402^00<0002^0:h0102^100000<0d0000A00

904@00<0004`0C003`4`20002@4_00<0004/0B`03@4/0`0000@12@00088003moo`03001oogoo02mo

o`00J7oo00<0000S02<00`0S0P000`0Y00<0002^0:h03P2^00<0002^0:h010001@3@00<0004@0A00

8`4@00<0004`0C005`4`1`000`4_00<0004/0B`03`4/0`0000<0PP00Ool0?Woo00<007ooOol0;Woo

000fOol00`00Oomoo`0^Ool00`0002<08`0302<00`0002T0:@0202T00`000:h0[P0>0:h400090=00

0`000A01400S0A000`000C01<00N0C05000B0B`200000`22001oo`0mOol00`00Oomoo`0^Ool003Io

o`03001oogoo02eoo`0300008`0S00808`8000D0:@030000[P2^00X0[P@000d0d0030001404@02@1

40030001<04`0201<0040001C`00000A0B`200000`22001oo`0lOol00`00Oomoo`0^Ool003Ioo`03

001oogoo02eoo`0300008`0S008000H0:@030000[P2^00L0[P@000D0d0030000d03@00P0d0030001

404@02D140030001<04`0201<0040001C`5?0Dl3000?0B`200000`22001oo`0iOol3000`Ool003Io

o`03001oogoo02aoo`0400008`0S000802T00`000:h0[P030:h400090=000`000=00d0080=000`00

0A01400U0A000`000C01<00Q0C000`000Dl1C`030Dl3000<0B`01@000@8000220000>goo00<007oo

Ool02goo0P000goo10006Woo001TOol0100002<00000200Y00<0002^0:h010003@3@00<0003@0=00

203@00<0004@0A009@4@00<0004`0C008@4`00<0005?0Dl01P5?0P002`4/00D000420000PP0003Yo

o`03001oogoo00Yoo`04001oogoo0006Ool00`00Oomoo`0GOol006Aoo`8000X0:@<00140d0030000

d03@00P0d0030001404@01`140d00201<0030001C`5?00P1C`<000P1;00300010P42008003Yoo`03

001oogoo00Aoo`@0009oo`04001oogoo0006Ool00`00Oomoo`0GOol006=oo`030000:@0Y00P0:@03

0000C@0001<0d0030000d03@00P0d0030001404@00P141@000T1<@040001D@5A0E48000H0C000`00

0Dl1C`0;0Dl200070B`00`000@810P02000iOol00`00Oomoo`0:Ool01000Oomoo`001Woo00<007oo

Ool05goo000fOol00`00Oomoo`0YOol00`0002T0:@0802T00`0004d0000M0=0=000M0C400`000E41

D@090E47000A0C000`000Dl1C`0=0Dl300040B`010000@810P420P00>7oo00<007ooOol02Woo00@0

07ooOol000Aoo`8001Yoo`00=Woo00<007ooOol0:Goo00<0000Y02T01P0Y0P000P1=00<0003@0=00

5`3@10000P3a00<0004a0C409@4a00<0005A0E40405A1`002`4`00<0005?0Dl03`5?0`000P4/00@0

00420@810P8003Moo`03001oogoo00Yoo`04001oogoo0004Ool00`00Oomoo`0IOol003Ioo`03001o

ogoo02Qoo`030000:@0Y00D0:@8000@0C@030000d03@0180d0D000H0l@030001<@4a02D1<@030001

D@5A01L1D@P000<1<0030001C`5?0181C`<000@10P8003Ioo`03001oogoo00]oo`8000Ioo`8001Uo

o`00=Woo00<007ooOol0:7oo00<0000Y02T0100Y00<0001=04d00`1=00<0003@0=00403@10002P3a

00<0004a0C409@4a00<0005A0E407`5A1@005@5?0P00104200<007ooOol0<goo0P00<7oo001POol0

0`0002T0:@0302T2000604d00`000=00d00;0=0500030?400`000?40l@080?400`000C41<@0U0C40

0`000E41D@0R0E4010000G000000505?0P00104200<007ooOol0<goo00<007ooOol0;Woo001POol0

0`0002T0:@0202T00`0004d0C@0604d00`000=00d0070=0400080?400`000?40l@080?400`000C41

<@0U0C400`000E41D@0R0E4010000G01L05`0`004P5?0P00104200<007ooOol0<Woo00<007ooOol0

;Woo000fOol00`00Oomoo`0VOol0100002T0:@0Y0P002@1=00<0003@0=000`3@10005P3a00<0004a

0C409P4a00<0005A0E408P5A00<0005`0G00105`0P00405?00<0005W00000`4200<007ooOol0<Woo

00<007ooOol0;Woo000fOol00`00Oomoo`0VOol0100002T000002P1=00<0003@0=0010006P3a00<0

004a0C409P4a00<0005A0E408`5A00<0005`0G001@5`0`003@5?00@0005W0FL000<10P03001oogoo

035oo`03001oogoo02ioo`00=Goo00<007ooOol09Woo00<0000Y0000301=0`007P3a00<0004a0C40

9P4a00<0005A0E408`5A00<0005`0G00205`0P00305?00@0005W0FL000810P03001oogoo035oo`03

001oogoo02ioo`00=Goo00<007ooOol09Woo0P002`1=0`005P3a00<0003a0?401`3a00<0004a0C40

9P4a00<0005A0E408`5A00<0005`0G002P5`0`002@5?00D0005W0FL1I`0000810P03001oogoo035o

o`03001oogoo02eoo`00GGoo00<0001=04d02P1=00@0002?08l001H0l@030000l@3a00L0l@030001

<@4a01`1<@h00281D@030001L05`00d1L0<000L1C`040001I`5W00020@800`00Oomoo`0aOol00`00

Oomoo`0]Ool005eoo`030000C@1=00P0C@8000<0S`030000l@3a01@0l@030000l@3a00L0l@030001

<@4a00P1<A@000X1<P040001DP5B0E88000J0E400`000G01L00@0G0200050Dl01@000FL1I`5W0000

0P4200<007ooOol0<7oo00<007ooOol0;Goo001LOol00`0004d0C@0804d00`0008l0S`0308l00`00

0?40l@0D0?400`000?40l@050?4=000N0C800`000E81DP090E88000B0E400`000G01L00B0G030002

0Dl00`000FL1I`020FL00`000@80000aOol2000_Ool003Eoo`03001oogoo02Aoo`030000C@1=00H0

C@8000H0S`030000l@3a01P0l@@000814P030001<P4b02H1<P030001DP5B0141DPP000/1D@030001

L05`01@1L08000030Dl0005W00<1I`0300010P00035oo`03001oogoo02eoo`00=Goo00<007ooOol0

97oo00<0001=04d01@1=00<0002?08l01@2?00<0003a0?405@3a10001P4B00<0004b0C809P4b00<0

005B0E806@5B20000`5A00<0005`0G005P5`0P001@5W0P00<Goo00<007ooOol0;Goo000eOol00`00

Oomoo`0SOol00`0004d0C@0404d2000808l00`000?40l@0A0?4500090A800`000C81<P0V0C800`00

0E81DP0Q0E85000H0G0200050FL2000`Ool00`00Oomoo`0]Ool003Eoo`03001oogoo02=oo`030000

C@1=0080C@8000X0S`030000l@3a00`0l@D000@14P0300014P4B00L14P030001<P4b02H1<P030001

DP5B02@1DP030001LP00008001D1L0030001S00000D1I`03001oogoo02ioo`03001oogoo02eoo`00

FWoo00<0001=04d00P1=00<0002?08l02P2?00<0003a0?40203a10002@4B00<0004B0A801`4B00<0

004b0C809P4b00<0005B0E80905B00<0005b0G800P5b0P00505`00<0006<0000105W00<007ooOol0

;Woo00<007ooOol0;Goo001JOol00`0004d0C@02000=08l00`000?40l@040?44000=0A800`000A81

4P070A800`000C81<P0V0C800`000E81DP0T0E800`000G81LP040G83000A0G0010000H`1S000105W

00<007ooOol0;Goo00<007ooOol0;Goo000eOol00`00Oomoo`0ROol00`0004d0000?08l00`000?40

l@04000K0A800`000C81<P0V0C800`000E81DP0T0E800`000G81LP070G83000>0G001@000H`1S06<

00000`5W00<007ooOol0;Goo00<007ooOol0;Goo000eOol00`00Oomoo`0QOol3000@08l3000O0A80

0`000C81<P0V0C800`000E81DP0T0E800`000G81LP0:0G83000;0G000`000H`1S0020H`010000FL1

I`00;Woo0P00;goo000eOol00`00Oomoo`0QOol00`0008l0S`0>08l3000Q0A800`000C81<P0V0C80

0`000E81DP0T0E800`000G81LP0=0G8300080G000`000H`1S0020H`01@000FL1I`5W0000;Woo00<0

07ooOol0;Goo000eOol00`00Oomoo`0QOol00`0008l0S`0<08l200020;400`000A814P0E0A800`00

0A814P070A800`000C81<P0L0C8>000S0E800`000G81LP0@0G8200060G000`000H`1S0030H`01000

0FL1I`00;Woo00<007ooOol0;Goo000eOol00`00Oomoo`0POol2000<08l200040;400`000A814P0E

0A800`000A814P070A800`000C81<P080C8D000:0C<010000G<1L`5c20006`5B00<0005b0G804P5b

0`00105`00<0006<0H`00`6<00@0005W0FL002eoo`03001oogoo02eoo`00F7oo00<0002?08l02P2?

00<0002a0;40102a00<0004B0A805@4B00<0004B0A801@4B3@007P4c00<0005c0G<02@5c20004`5B

00<0005b0G805@5b0`0000<1L0000H`01@6<00<0005W0000;Goo00<007ooOol0;Goo001HOol00`00

08l0S`0808l200070;400`000A814P0E0A8010000A814P4B10000P4C00<0004c0C<09P4c00<0005c

0G<04@5c20002`5B00<0005b0G80605b0P001`6<0P00;Goo0P00;Woo000eOol00`00Oomoo`0OOol2

000808l200080;400`000A814P0F0A8400060A<00`000C<1<`0V0C<00`000G<1L`0I0G<800030E80

0`000G81LP0I0G8200070H`2000]Ool00`00Oomoo`0/Ool003Eoo`03001oogoo01moo`8000H0S`80

00X0/@0300014P4B01414PD000X14`030001<`4c02H1<`030001L`5c0241L`D001X1LP030001[`00

00L1S003001oogoo02]oo`03001oogoo02aoo`00=7oo00<007ooOol087oo0P001@2?00<0002a0;40

2P2a00<0004B0A803@4B10001@4C00<0004C0A<01`4C00<0004c0C<09P4c00<0005c0G<0905c00<0

006C00000P005`5b00@0006_0Jl000H1S003001oogoo02]oo`03001oogoo02aoo`00=7oo00<007oo

Ool087oo00<08P0008l00P2?0P003@2a00<0004B0A80204B1@002@4C00<0004C0A<01`4C00<0004c

0C<09P4c00<0005c0G<0905c00<0006C0I<00P6C0P005@5b00D0006_0Jl1[`0000D1S003001oogoo

02Yoo`8002ioo`00EWoo0P000P2?0P003`2a00<0004B0A80104B10003@4C00<0004C0A<0204C00<0

004c0C<09P4c00<0005c0G<0905c00<0006C0I<0106C0`004P5b00<0006_0Jl00P6_00<0006<0H`0

0`6<00<007ooOol0:Woo00<007ooOol0;7oo001FOol4000A0;400`000A814P04000A0A<00`000A<1

4`080A<00`000C<1<`0V0C<00`000G<1L`0T0G<00`000I<1T`070I<3000?0G800`000Jl1[`030Jl0

0`000H`1S0020H`00`00Oomoo`0ZOol00`00Oomoo`0/Ool005Ioo`8001<0/@<001D14`0300014`4C

00P14`030001<`4c02H1<`030001L`5c02@1L`030001T`6C00X1T`<000`1LP030001[`6_00<1[`03

0001S06<0081S003001oogoo02Yoo`03001oogoo02aoo`00=7oo00<007ooOol07Woo00<0000R0000

4@2a0`008P4C00<0004c0C<09P4c00<0005c0G<0905c00<0006C0I<03@6C0`002@5b00<0006_0Jl0

106_00D0006<0H`1S00002aoo`03001oogoo02aoo`00=7oo00<007ooOol07Woo0`003`2a0P000P3B

00<0004C0A<0804C00<0004c0C<09P4c00<0005c0G<08`5c00<0006C0I<04@6C0P001`5b00<0006_

0Jl01@6_00@0006<0H`002aoo`03001oogoo02aoo`00=7oo00<007ooOol07Woo0`003@2a0P00103B

00<0004C0A<05@4C00<0004C0A<0204C00<0004c0C<0704c3P008P5c00<0006C0I<04`6C0`00105b

00<0006_0Jl01P6_00<0006<0000;7oo00<007ooOol0;7oo000dOol00`00Oomoo`0NOol3000;0;42

00060=800`000A<14`0E0A<00`000A<14`080A<00`000C<1<`080C<D000:0E@010000G@1M05d2000

6P5c00<0006C0I<05P6C0`0000<1LP000Jl0206_00<0006<0000:goo00<007ooOol0;7oo001DOol2

00000`0W0000/@090;400`000=80dP060=800`000A<14`0E0A<00`000A<14`060A<=000N0E@00`00

0G@1M0090G@7000C0G<00`000I<1T`0I0I<2000:0Jl2000YOol00`00Ool0000^Ool005Aoo`800003

02L0002a00L0/@8000T0dP0300014`4C01D14`0400014`4C0A<500020C@00`000E@1E00V0E@00`00

0G@1M00@0G@8000;0G<00`000I<1T`0J0I<2000:0Jl00`00Oomoo`0XOol20006Ool2000VOol003Ao

o`03001oogoo01eoo`80000302L0002a00D0/@8000`0dP0300014`4C01<14`D000L1=0030001E05D

02H1E0030001M05d01P1M0P000<1L`030001T`6C01X1T`030001d@0000T1[`03001oogoo02Uoo`03

001oogoo00=oo`04001oogoo000UOol003Aoo`03001oogoo01eoo`80000302L0002a00<0/@8000h0

dP0300014`4C00l14`@000`1=0030001E05D02H1E0030001M05d0201M0D001/1T`040001d@7A0008

0Jl00`00Oomoo`0YOol00`00Oomoo`03Ool01000Oomoo`009Goo000dOol00`00Oomoo`0MOol01000

02L09`000P2a0P00403B00<0004C0A<02P4C1@00404d00<0005D0E@09P5D00<0005d0G@08`5d00<0

006D00000P00606C00D0007A0M41d@0000L1[`03001oogoo02Uoo`03001oogoo00=oo`04001oogoo

000UOol003Aoo`03001oogoo01eoo`0300009`0W00<00180dP0300014`4C00D14`D000X1=0030001

=04d00P1=0030001E05D02D1E0030001M05d02@1M0030001U06D0081U0<001D1T`030001d@7A0081

d@030001[`6_00@1[`03001oogoo02Uoo`03001oogoo00=oo`04001oogoo000UOol003Aoo`03001o

ogoo01aoo`8000809`030000dP3B0180dP0300014`4C00D000l1=0030001=04d00P1=0030001E05D

02D1E0030001M05d02@1M0030001U06D00D1U0<00141T`030001d@7A00@1d@030001[`6_00<1[`03

001oogoo02Yoo`03001oogoo009oo`04001oogoo000AOol5000?Ool005=oo`0500009`0W02L0000D

0=83000D0C@00`000C@1=0080C@00`000E@1E00U0E@00`000G@1M00S0G@00`000I@1U0090I@3000>

0I<00`000M41d@050M400`000Jl1[`020Jl00`00Oomoo`0ZOol00`00Oomoo`03Ool2000COol01000

Oomoo`003goo001COol00`0002L09`02000B0=83000F0C@00`000C@1=0090C@00`000E@1E00T0E@0

0`000G@1M00S0G@00`000I@1U00<0I@4000:0I<00`000M41d@060M400`000Jl1[`020Jl00`00Oomo

o`0YOol00`00Oomoo`0HOol00`00Oomoo`0@Ool003=oo`03001oogoo01eoo`0300009`0W00800100

dP800080l`030001=04d0201=0030001E05D02@1E0030001M05d02<1M0030001U06D0101U0<000L1

T`030001d@7A00L1d@050001[`6_0Jl0000ZOol2000KOol00`00Oomoo`0?Ool003=oo`03001oogoo

01eoo`0300009`0W008000h0dP8000@0l`030001=04d0201=0030001E05D02@1E0030001M05d02<1

M0030001U06D01<1U0<000@1T`030001d@7A00P1d@040001[`6_000[Ool00`00Oomoo`0JOol00`00

Oomoo`0>Ool003=oo`03001oogoo01eoo`0300009`0W008000`0dP8000L0l`030001=04d01<1=003

0001=04d00T1=0030001E05D02@1E0030001M05d02<1M0030001U06D01H1U0<000030I<0007A00X1

d@030001[`0002]oo`03001oogoo01Qoo`03001oo`00011oo`00<goo00<007ooOol07Goo00D0000W

0000;00000/0dP030000l`3c00L0l`030001=04d01<1=0030001=04d00T1=0030001E05D01/1E0h0

0241M0030001U06D01T1U08000`1d@8002]oo`03001oogoo01Qoo`@000moo`00Dgoo00<0000W0000

0P0/00<0003B0=801P3B0P002P3c00<0004d0C@04`4d00<0004d0C@02@4d00<0005D0E@01`5D5000

2@5D00<0005d0G@00P5d2@005`5d00<0006D0I@06`6D0P00307A00<007ooOol0:Goo00<007ooOol0

:goo001COol00`0002L0000202`00`000=80dP040=82000<0?<00`000C@1=00C0C@00`000C@1=007

0C@<000M0E@00`000G@1M00;0G@:000=0G@00`000I@1U00K0I@00`000M<0000;0M400`00Oomoo`0Y

Ool00`00Oomoo`0[Ool005=oo`8000<0;0030000dP3B0080dP8000h0l`030001=04d01<1=0030001

=04d0081=0D00081=0030001E05D02@1E0030001M05d01D1M0T000@1M0030001U06D01X1U0050001

d`7C0M<0000:0M400`00Oomoo`0YOol00`00Oomoo`0[Ool003=oo`03001oogoo01eoo`8000<0;003

0000dP3B00800100l`030001=04d01@1=0@000L1=0030001E05D02@1E0030001M05d01h1M0H001/1

U0030001d`7C0081d`030001d@7A00L1d@03001oogoo02Uoo`03001oogoo02]oo`00<goo00<007oo

Ool07Goo0P000`0/0`004P3c00<0004d0C@03`4d1@002`4d00<0005D0E@0905D00<0005d0G@08P5d

00<0006E00000P00606D00<0007C0M<00`7C00<0007A0M401P7A00<007ooOol0:Goo00<007ooOol0

:goo000cOol00`00Oomoo`0MOol2000302`00`000?<0l`0C0?<00`000C@1=0090C@500040C@00`00

0C@1=00:0C@00`000E@1E00S0E@00`000G@1M00R0G@00`000ID1U@020ID3000E0I@00`000M<1d`04

0M<200060M400`00Oomoo`0XOol2000]Ool003=oo`03001oogoo01eoo`030000;00/0080;0030000

l`3c01<0l`030001=04d00D1=0@000T1=0030001=04d00X1=0030001E05D02<1E0030001M05d0281

M0030001U@6E00D1U@<00141U0030001d`7C00L1d`030001d@7A0081d@03001oogoo02Yoo`03001o

ogoo02]oo`00Dgoo00@0000/02`0;08001D0l`030001=04d00D000d1=0030001=04d00X1=0030001

E05D02<1E0030001M05d0241M0030001U@6E00T1U@<000h1U0030001d`7C00P1d`050001d@7A0M40

000/Ool00`00Oomoo`0[Ool005=oo`070000;00/02`0000`0000503c0`004P4d00<0004d0C@02P4d

00<0005D0E@08`5D00<0005d0G@08@5d00<0006E0ID0306E0`002`6D00<0007C0M<02@7C00@0007A

0M4002aoo`8002aoo`00<goo00<007ooOol07Goo00L0000/02`0;0000300000B0?<3000Q0C@00`00

0E@1E00S0E@00`000G@1M00Q0G@00`000ID1U@0?0ID300080I@00`000M<1d`0:0M<00`000M40000]

Ool00`00Oomoo`0ZOol003=oo`03001oogoo01eoo`040000;00/000203000`000?<0l`0>0?<20003

0AD00`000C@1=00N0C@00`000E@1E00S0E@00`000G@1M00Q0G@00`000ID1U@0B0ID300040I@00`00

0M<1d`0<0M<2000]Ool00`00Oomoo`0ZOol0039oo`03001oogoo01ioo`040000;00/000203000`00

0?<0l`0<0?<200050AD00`000C@1=00N0C@00`000E@1E00S0E@00`000G@1M00Q0G@00`000ID1U@0E

0ID300000`6D0001d`0>0M<00`00Oomoo`0[Ool00`00Oomoo`0ZOol0039oo`03001oogoo01ioo`04

0000;00/000303000`000?<0l`090?<200070AD00`000C@1=00A0C@00`000C@1=00;0C@00`000E@1

E00R0E@00`000G@1M00Q0G@00`000ID1U@0H0ID2000?0M<00`00Oomoo`0[Ool00`00Oomoo`0ZOol0

05Aoo`030000;00000<0<0030000l`3c00L0l`8000X15@030001=04d0101=0030001=04d00/1=003

0001E05D0281E0030001M05d0241M0030001U@6E01T1U@8000d1d`03001oogoo02aoo`03001oogoo

02Yoo`00E7oo0P00100`00<0003c0?<01@3c0P00304E00<0004d0C@0404d00<0004d0C@02`4d00<0

005D0E@0405D5`007`5d00<0006E0ID0606E00@0007d0O@000`1d`03001oogoo02]oo`8002aoo`00

E7oo0P00100`00<0003c0?<00`3c0P003P4E00<0004d0C@0404d00<0004d0C@02@4d5@004P5e00<0

005e0GD00P5e2@005@5d00<0006E0ID06@6E00@0007d0O@1m08000X1d`03001oogoo02aoo`03001o

ogoo02Yoo`00<Woo00<007ooOol07goo0P001@0`00<0003c0?<00P00404E00<0004d0C@05`4d1@00

0P5E00<0005e0GD08P5e00<0005e0GD02`5e20003@5d00<0006E0ID06@6E00<0007d0O@00`7d00<0

007C0M<01`7C00<007ooOol0;7oo00<007ooOol0:Woo000bOol00`00Oomoo`0OOol00`000300<004

0303000C0AD00`000C@1=00A0C@500070ED00`000GD1M@0R0GD00`000GD1M@0C0GD900040G@00`00

0ID1U@0H0ID00`000O@1m0050O@00`000M<1d`050M<00`00Oomoo`0]Ool00`00Oomoo`0ZOol0039o

o`03001oogoo01moo`030000<00`00@0<00300015@4E01<15@030001=04d00/1=0H000d1E@030001

M@5e0241M@030001M@5e01`1M@H001T1U@030001m07d00H1m0030001d`7C00@1d`03001oogoo02eo

o`03001oogoo02Yoo`00<Woo00<007ooOol07goo00<0000`0300100`00<0004E0AD04`4E00<0004d

0C@01P4d1@00105E00<0005E0ED0305E00<0005e0GD08@5e00<0005e0GD0805e00<0006e00000`00

5@6E00<0007d0O@01`7d00<0007C0M<00`7C00<007ooOol0;Goo00<007ooOol0:Woo001EOol00`00

0300<00203000`0007<0000E0AD00`000C@1=00500090ED00`000ED1E@0<0ED00`000GD1M@0Q0GD0

0`000GD1M@0O0GD00`000KD1]@040KD3000B0ID00`000O@1m0080O@200030M<00`00Oomoo`0]Ool0

0`00Oomoo`0ZOol005Eoo`030000<00`0080<0030000L`0001D15@<000h1E@030001E@5E00`1E@03

0001M@5e0241M@030001M@5e01l1M@030001]@6e00L1]@@000d1U@030001m07d00/1m0030001d`00

031oo`03001oogoo02Yoo`00<Woo00<007ooOol087oo00<0000`03000P0`00@0001c07<001815@<0

0101E@030001E@5E00`1E@030001M@5e0201M@030001M@5e0201M@030001]@6e00/1]@@000T1U@03

0001m07d00`1m080031oo`03001oogoo02Yoo`00<Woo00<007ooOol087oo00D0000`0300<00000<0

L`0300015@4E00h15@8000<15P030001E@5E01`1E@030001M@5e0201M@030001M@5e01l1M@030001

]@6e0101]@<000H1U@030001m07d00d1m003001oogoo02eoo`8002aoo`00<Woo00<007ooOol08Goo

00@0000`030000<0L`0300015@4E00`15@8000D15P030001E@5E01d1E@030001M@5e01l1M@030001

M@5e01l1M@030001]@6e01<1]@@000030ID0007d00l1m003001oogoo02ioo`03001oogoo02Yoo`00

<Woo00<007ooOol08Goo00<0000`00001@1c00<0004E0AD02@4E0P00204F00<0005E0ED0305E00<0

005E0ED03@5E00<0005e0GD07`5e00<0005e0GD07`5e00<0006e0KD05`6e0P003`7d00<007ooOol0

;goo00<007ooOol0:Woo000bOol00`00Oomoo`0QOol00`000300000507<00`000AD15@080AD00`00

0AH15P080AH00`000ED1E@0<0ED00`000ED1E@0=0ED00`000GD1M@0O0GD00`000GD1M@0N0GD00`00

0KD1]@0H0KD00`000OH0000>0O@00`00Oomoo`0`Ool00`00Oomoo`0YOol005Ioo`030000<00000D0

L`0300015@4E00H15@8000/15P030001E@5E00`1E@030001E@5E00d1E@030001M@5e01l1M@030001

M@5e01h1M@030001]@6e01P1]@040001mP7f000<0O@2000bOol00`00Oomoo`0YOol005Moo`030000

L`1c00D0L`0300015@4E00<15@8000h15P030001E@5E00/1E@030001E@5E00d1E@030001M@5e01l1

M@030001M@5e01h1M@030001]@6e01L1]@030001mP7f0081mP8000X1m003001oogoo035oo`03001o

ogoo02Uoo`00<Woo00<007ooOol08Woo00<0001c07<01@1c00@0004E0AD15@8001015P030001E@5E

01`1E@030001M@5e01H1M@`001`1M@030001]@6e01P1]@030001mP7f00@1mP030001m07d00H1m080

03=oo`03001oogoo02Uoo`00<Woo00<007ooOol08Woo00<0001c07<01P1c0`004`4F00<0005E0ED0

6`5E00<0005e0GD01P5e4000205f00@0006F0IH1UPP001@1M@030001]@6e01L1]@030001mP7f00H1

mP030001m07d00D1m08003=oo`03001oogoo02Uoo`00<Goo00<007ooOol097oo00<0001c07<01@1c

00<0004F0AH04`4F00<0005E0ED06@5E2`00605f00<0006F0IH02@6F2000305e00<0006e0KD05`6e

00<0007f0OH01`7f00<0007d0O@0107d00<007ooOol0<Woo00<007ooOol0:Goo000aOol00`00Oomo

o`0TOol00`0007<0L`0507<2000D0AH00`000ED1E@0:0ED00`000ED1E@060ED600020EH00`000GH1

MP0N0GH00`000IH1UP0A0IH800030GD00`000KD1]@0G0KD00`000OH1mP090OH00`000O@1m0020O@2

000bOol00`00Ool0000[Ool005Uoo`030000L`1c00<0L`030000]@0001D15P030001E@5E00T1E@04

0001E@5E0ED500080EH00`000GH1MP0N0GH00`000IH1UP0I0IH5000H0KD00`000OH1mP0:0OH20002

0O@2000cOol20006Ool20003Ool4000LOol005Uoo`030000L`1c00<0L`040000]@2e000D0AH00`00

0ED1E@070ED6000>0EH00`000GH1MP0M0GH00`000IH1UP0L0IH00`000KH00003000C0KD00`000OH1

mP0=0OH3000eOol00`00Oomoo`03Ool01000Oomoo`001Woo00<007ooOol06Goo001IOol00`0007<0

L`0207<01@000;D0]@2e00005@4F00<0005E0ED01P0000<1EP000EH04@5F00<0005f0GH07@5f00<0

006F0IH06`6F00<0006f0KH0106f10003`6e00<0007f0OH03P7f0P00=Goo00<007ooOol00goo00@0

07ooOol000Ioo`03001oogoo01Uoo`00<Goo00<007ooOol09Woo00D0001c07<0L`0000@0]@030001

5P4F01415P@001X1EP030001MP5f01d1MP030001UP6F01/1UP030001]P6f00P1]P@000X1]@030001

mP7f00h1mP<003Eoo`03001oogoo00=oo`04001oogoo0006Ool00`00Oomoo`0IOol0035oo`03001o

ogoo02Ioo`050000L`1c07<000040;D00`000AH15P0?0AH200020CL00`000EH1EP0I0EH00`000GH1

MP0M0GH00`000IH1UP0J0IH00`000KH1]P0=0KH400060KD00`000OH1mP0>0OH2000fOol00`00Oomo

o`03Ool01000Oomoo`0017oo0P0077oo000aOol00`00Oomoo`0WOol00`0007<000060;D00`000AH1

5P0<0AH200040CL00`000EH1EP060EH00`000EH1EP0A0EH00`000GH1MP0K0GH00`000IH1UP0K0IH0

0`000KH1]P0A0KH400000`6e0001mP0?0OH3000fOol00`00Oomoo`03Ool01000Oomoo`0017oo00<0

07ooOol06goo000aOol00`00Oomoo`0WOol00`0007<000060;D00`000AH15P0:0AH200070CL00`00

0EH1EP050EH00`000EH1EP0A0EH00`000GH1MP0K0GH00`000IH1UP0K0IH00`000KH1]P0E0KH2000@

0OH3000fOol00`00Oomoo`04Ool20006Ool2000KOol005aoo`030000]@2e00H0]@0300015P4F00L1

5P8000T1=`030001EP5F00D1EP030001EP5F0141EP030001MP5f01/1MP030001UP6F01X1UP030001

]P6f01H1]P030001m`0000h1mP0300024@0003Moo`03001oogoo02Uoo`00G7oo00<0002e0;D01P2e

00<0004F0AH01@4F0P00304g00<0005F0EH0105F00<0005F0EH04@5F00<0005f0GH06`5f00<0006F

0IH06P6F00<0006f0KH05P6f00<0007g0OL00P002`7f00@0008A000003Ioo`<002Yoo`00<Goo00<0

07ooOol0:Goo00<0002e0;D01P2e00<0004F0AH00P4F0P003P4g00<0005F0EH06@5F00<0005f0GH0

6P5f00<0006F0IH06@6F00<0006f0KH05P6f00<0007g0OL00`7g00<0007f0OH0207f00<0008A0000

>7oo0P00:Woo000aOol00`00Oomoo`0YOol00`000;D0]@060;D00`000AH15P02000A0CL00`000EH1

EP0H0EH00`000GH1MP0J0GH00`000IH1UP0I0IH00`000KH1]P0F0KH00`000OL1m`040OL00`000OH1

mP060OH010000Q424@00>Goo00<007ooOol0:7oo000aOol00`00Oomoo`0ZOol00`000;D0]@060;D2

000C0CL00`000EH1EP0H0EH00`000GH1MP0J0GH00`000IH1UP0I0IH00`000KH1]P0E0KH00`000OL1

m`060OL00`000OH1mP040OH01@000Q424@8A0000>Goo00<007ooOol0:7oo000aOol00`00Oomoo`0Z

Ool00`000;D0]@060;D2000D0CL00`000EH1EP020EH00`000EH1EP0B0EH00`000GH1MP0J0GH00`00

0IH1UP0H0IH00`000KH1]P0E0KH00`000OL1m`080OL00`000OH1mP030OH010000Q424@00>Woo00<0

07ooOol0:7oo000aOol00`00Oomoo`0[Ool00`000;D0]@040;D010000?L0m`004`4g00<0005F0EH0

0P5F00<0005F0EH04`5F00<0005f0GH0305f5000506F00<0006f0KH05@6f00<0007g0OL02@7g0P00

0P7f00D0008A0Q424@0003Yoo`03001oogoo02Qoo`00Ggoo00<0002e0;D0102e00D0003g0?L0m`00

01<1=`050001EP5F0EH0000C0EHA000=0IL00`000IL1U`040IL=00060IH00`000KH1]P0E0KH00`00

0OL1m`0<0OL00`000OH000020Q400`00Oomoo`0iOol00`00Oomoo`0XOol0061oo`030000]@2e0080

]@030000m`3g0080m`030001=`4g0141=`050001EP5F0EH0000=0EH600020GL00`000IL1U`0I0IL0

0`000IL1U`0A0IL8000F0KH00`000OL1m`0=0OL01@000Q424@8A0000>goo00<007ooOol0:7oo000`

Ool00`00Oomoo`0^Ool01@000;D0]@2e00001@3g00<0004g0CL04@4g00<0005F0EH0205F1P002@5g

00<0006G0IL0606G00<0006G0IL05P6G00<0006h0KP00`004P6f00<0007g0OL03@7g0P000P8A00<0

07ooOol0>Woo00<007ooOol0:7oo000`Ool00`00Oomoo`0^Ool010000;D0]@001`3g00<0004g0CL0

404g00<0005F0EH00P5F1P003`5g00<0006G0IL0606G00<0006G0IL05P6G00<0006h0KP00`6h1000

3@6f00<0007g0OL03@7g00D0008e00024@0003eoo`03001oogoo02Qoo`00<7oo00<007ooOol0;goo

00<0002e0000203g00<0004g0CL03`4g1@005@5g00<0006G0IL05`6G00<0006G0IL05P6G00<0006h

0KP0206h0`002P6f00<0007g0OL0307g00<0008e00000P8A00<007ooOol0>Woo0P00:Woo000`Ool0

0`00Oomoo`0_Ool2000:0?L00`000CL1=`0<0CL200020EP2000F0GL00`000IL1U`0G0IL00`000IL1

U`0F0IL00`000KP1^00;0KP300060KH00`000OL1m`0=0OL01@000SD0008A0000?Woo00<007ooOol0

:7oo001SOol00`000?L0m`090?L00`000CL1=`090CL200040EP2000G0GL00`000IL1U`0F0IL00`00

0IL1U`0E0IL00`000KP1^00?0KP400020KH00`000OL1m`0<0OL01P000SD2=@000Q4003ioo`03001o

ogoo02Qoo`00I7oo00<0003g0?L0203g00<0004g0CL01P4g0`001`5H00<0005g0GL05@5g00<0006G

0IL05P6G00<0006G0IL05@6G00<0006h0KP04`6h0P003P7g00@0008e0SD2=@8003moo`03001oogoo

02Qoo`00IGoo00<0003g0?L0203g00<0004g0CL00`4g0P002@5H1@00505g00<0006G0IL05P6G00<0

006G0IL0506G00<0006h0KP0506h00<0007h0000307g00@0008e0SD2=@80041oo`03001oogoo02Qo

o`00<7oo00<007ooOol0<goo00<0003g0?L0203g00<0004g0CL00P002@5H0P000`5H00@0005g0000

0081M`8000l1M`030001U`6G01D1U`030001U`6G01@1U`030001^06h01<1^0040001n07h0OP20009

0OL00`000SD2=@020SD20010Ool00`00Oomoo`0XOol0031oo`03001oogoo03Aoo`030000m`3g00P0

m`800101F0030001M`5g00D1M`<00081M`8000P1M`030001U`6G01D1U`030001U`6G01<1U`030001

^06h01<1^0030001n07h00@1n0030001m`7g00D1m`030002=@8e00<2=@03001oogoo03moo`03001o

ogoo02Qoo`00<7oo00<007ooOol0=Goo00<0003g0?L01P3g00<0004i0000205H00<0005H0EP01P5H

00<0005g0GL02`5g0P000`5g0P0000<1M`000IL05P6G00<0006G0IL04`6G00<0006h0KP04P6h00<0

007h0OP01P7h00<0007g0OL0107g00<0008e0SD00P8e00<007ooOol0@7oo00<007ooOol0:7oo000`

Ool00`00Oomoo`0fOol00`000?L0m`050?L010000CT1>@001@5H0P002P5H00<0005g0GL04@5g0`00

00<1U`0000004`6G00<0006G0IL04P6G00<0006h0KP04P6h00<0007h0OP0207h0P000`7g00<0008e

0SD00P8e00<007ooOol0@Woo00<007ooOol09goo001ZOol00`000?L0m`030?L00`000CT1>@020CT0

1@000EP1F05H00003@5H00<0005g0GL04P5g00@0006G0IL1U`8000<1U`8000/1U`030001U`6G01<1

U`030001^06h0141^0030001n07h00/1n0030001m`0000@2=@03001oogoo049oo`8002Uoo`00Jgoo

00<0003g0?L00P3g00<0004i0CT00`4i00<0005H0EP03P5H00<0005g0GL04P5g00<0006G0IL0206G

0P000P6G0P001@6G00<0006G0IL04P6G00<0006h0KP04@6h00<0007h0OP03@7h00<0008e0SD00P8e

00<007ooOol0A7oo00<007ooOol09goo000`Ool00`00Oomoo`0iOol010000?L0m`00104i0P0000<1

>@000EP03`5H00<0005g0GL04@5g00<0006G0IL03P6G0P000`6G0P004`6G00<0006h0KP0406h00<0

007h0OP03@7h0P000`8e00<007ooOol0AGoo00<007ooOol09goo000`Ool00`00Oomoo`0jOol00`00

0?L000030CT00`000CT1>@020CT00`000EP1F00>0EP00`000GL1M`0A0GL00`000IL1U`0B0IL01000

0IL000000P6G0P00306G00<0006h0KP0406h00<0007h0OP0307h0P0000<2>0000SD00P8e00<007oo

Ool0AGoo00<007ooOol09goo000`Ool00`00Oomoo`0kOol00`000CT000080CT2000?0EP00`000GL1

M`0>0GLR00020IL200050IL00`000KP1^00?0KP00`000OP1n00<0OP01@000SP2>08h00000P8e00<0

07ooOol0AWoo00<007ooOol09goo000`Ool00`00Oomoo`0lOol00`000CT1>@090CT00`000EP1F00<

0EP00`000GL1M`080GL600030KX00`000KX1^P0A0KX00`000KX1^P070KX;000@0KP00`000OP1n00<

0OP01@000SP2>08h00000P8e00<007ooOol0Agoo00<007ooOol09goo001^Ool01000Ool000002P4i

00<0005H0EP0305H00@0005g0GL1M`H000T1^P030001^P6j0141^P030001^P6j00l1^P030001fP7J

00@000030KP0000000P1^0030001n07h00`1n0030002>08h0082>0030002=@0004Yoo`03001oogoo

02Moo`00LGoo0P002P4i00<0005H0EP02`5H1000406j00<0006j0KX03`6j00<0006j0KX03`6j00<0

007J0MX01@7J1@001@6h00<0007h0OP0307h00<0008h0SP00`8h0P00Bgoo00<007ooOol09goo001Z

Ool20006Ool2000:0CT00`000EP1F0070EP300020IX2000A0KX00`000KX1^P0>0KX00`000KX1^P0>

0KX00`000MX1fP090MX400000`6h00000002000;0OP200060SP00`00Oomoo`1:Ool00`00Oomoo`0W

Ool002moo`03001oogoo03Ioo`8000Uoo`<000T1>@030001F05H00@1F08000L1VP030001^P6j00h1

^P030001^P6j00h1^P030001^P6j00d1^P030001fP7J00h1fP8000D1n0@000@1n0030002>08h00@2

>08004aoo`8002Uoo`00;goo00<007ooOol0@Woo00<0002d00002@4i00<0005H0EP00`002P6J0P00

3`6j00<0006j0KX03@6j00<0006j0KX0306j00<0007J0MX03P7J0P0000<1n`0000002P7h10000`8h

00<007ooOol0CGoo00<007ooOol09goo000_Ool00`00Oomoo`0bOol2000?Ool00`000;@000090CT2

000?0IX2000>0KX00`000KX1^P0<0KX00`000KX1^P0;0KX00`000MX1fP0=0MX200050O/00`000OP1

n0060OP00`000SP2>0030SP5001=Ool00`00Oomoo`0WOol002moo`03001oogoo031oo`80019oo`@0

00H1>@030001V`6K008000l1VP030001^P6j00/1^P030001^P6j00/1^P030001^P6j00/1^P030001

fP7J00`1fP8000P1n`8000@1n08000D2>003001oogoo00Ioo`@004Ioo`03001oogoo02Moo`00N7oo

00<0002d00001@4i00<0006K0I/00P6K0`003@6J0P00306j00<0006j0KX02P6j00<0006j0KX02P6j

00<0007J0MX02`7J0P00307k0P0000<1n0000SP01@8h00<007ooOol03Goo1@00?goo00<007ooOol0

9goo001OOol00`00Oomoo`0GOol00`000;@000030CT00`000I/1V`060I/3000<0IX00`000KX1^P0:

0KX00`000KX1^P090KX00`000KX1^P090KX00`000MX1fP0:0MX2000?0O/200050SP2000GOol4000i

Ool00`00Oomoo`0WOol002moo`03001oogoo02]oo`8001]oo`@000030CT0006K00X1V`8000/1VP80

00X1^P030001^P6j00T1^P030001^P6j00P1^P030001fP7J00T1fP8000h1n`<000030Q/0008h00<2

>003001oogoo01eoo`D0039oo`8002Qoo`00;goo00<007ooOol0:Woo00<007ooOol07Goo00@0002d

000000d1V`<000X1VP030001^P6j00P1^P030001^P6j00L1^P030001^P6j00P1^P030001fP7J00P1

fP8000`1n`@000@26`030002>08h008002Moo`@002eoo`03001oogoo02Ioo`00;goo00<007ooOol0

9goo00<007ooOol08Goo1`00306K0P002@6J0P002@6j00<0006j0KX01P6j00<0006j0KX01P6j0P00

2@7J0P002`7k0`001`8K00@0008h0SP0031oo`@002Ioo`03001oogoo02Ioo`00;goo00<007ooOol0

9Goo0P009Woo0P000`6K10002P6K0`00206J0P001`6j00<0006j0KX01P6j00<0006j0KX01@6j00<0

007J0MX01`7J0P002P7k0`002P8K0`00=goo100087oo00<007ooOol09Woo000_Ool00`00Oomoo`0T

Ool00`00Oomoo`0WOol200060I/400090I/200080IX00`000KX1^P050KX00`000KX1^P050KX00`00

0KX1^P040KX00`000MX1fP060MX200080O/4000;0Q/30010Ool2000IOol30006Ool3000OOol005=o

o`03001oogoo02]oo`8000T1V`@000L1V`<000H1VP8000H1^P030001^P6j00@1^P030001^P6j00<1

^P030001fP7J00D1fP8000L1n`<000X26`H004Aoo`80009oo`8001Eoo`03001oogoo00Eoo`03001o

ogoo01ioo`00DGoo0P00<7oo0`002P6K10001P6K0`001@6J00<0006j0KX00`6j00<0006j0KX00`6j

00<0006j0KX00`6j00<0007J0MX0107J0P001P7k0`00208K1@000P7j0P00C7oo0P000goo0P003Woo

00<007ooOol01Goo00<007ooOol07Woo000_Ool00`00Oomoo`0NOol00`00Oomoo`0bOol700080I/4

00050I/200040IX200040KX00`000KX1^P020KX00`000KX1^P020KX00`000MX1fP030MX200050O/3

00060Q/500050OX2001EOol20002Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`0NOol002moo`03

001oogoo05Ioo`<000030GT0000000@000H1V`@000<1V`<000<1VP030001^P6j0081^P050001^P6j

0KX000030KX00`000MX1fP020MX200030O/400040Q/500050OX5001MOol30002Ool200000goo001o

o`06Ool00`00Oomoo`0NOol002ioo`03001oogoo01aoo`8003aoo`<000@1N@H000@1V`@00081V`80

0081VP800081^P050001^P6j0KX000020KX010000MX1fP7J0P000P7k0`000`8K1@000`7j2000IWoo

00@007oo000000Moo`03001oogoo01ioo`00;Woo00<007ooOol06Woo0P00@Goo1P00105i1P000P6K

1`0000D1VP000001^P000081^P030001^P000081fP8000050O/0000000026`0500000`7j00000009

0002Ool00`00Oomoo`1TOol30008Ool2000POol009=ooaP000060KX000000KX0007J5@001goo00<0

07ooOol0Ggoo00<007oo00000P00;Goo0017Ool2001BOolT000>Ool00`00Oomoo`1NOol3000`Ool0

04Eoo`8005mooa4001Ioo`03001oogoo05Uoo`03001oo`00008003=oo`00;Woo00<007ooOol0mgoo

0`00=Woo000^Ool00`00Oomoo`0AOol00`00Oomoo`3NOol6000hOol002ioo`03001oogoo00moo`80

08]oo`03001oogoo059oo`@003]oo`00;Woo00<007ooOol03Woo00<007ooOol0Rgoo00<007ooOol0

CGoo1P00?Woo000lOol00`00Oomoo`2>Ool00`00Oomoo`18Ool01000Oomoogoo1000@Goo000jOol2

002AOol00`00Oomoo`18Ool00`00Ool00002000GOol3000ZOol002ioo`03001oogoo00Qoo`03001o

ogoo0=]oo`<001]oo`03001oogoo02Uoo`00;Woo00<007ooOol01Goo00<007ooOol0fGoo00<007oo

00000`007Goo00<007ooOol0:Goo000^Ool00`00Oomoo`03Ool2002GOol00`00Oomoo`0mOol01000

Oomoogoo0`008Goo00<007ooOol0:Goo000^Ool00`00Oomoo`02Ool00`00Oomoo`2GOol00`00Oomo

o`0mOol01000Ool0000097oo00<007ooOol0:Goo000^Ool00`00Oomoo`2LOol00`00Oomoo`0hOol0

0`00Oomoo`04000VOol00`00Oomoo`0YOol0031oo`03001oogoo09Yoo`03001oogoo03Qoo`@002Qo

o`8002]oo`00;Woo0P00WGoo00<007ooOol0<Woo00<007ooOol01000F7oo000`Ool20002Ool40035

Ool00`00Oomoo`02Ool4001KOol003]oo`@00;ioo`03001oo`0000<005ioo`00@Goo1@000Woo0P00

Pgoo00<007ooOol0;Goo0`004goo0P000goo1000AGoo001:Ool20002Ool2001mOol00`00Oomoo`0X

Ool5000EOol01000Oomoo`001Woo00<007ooOol0@Woo001@Ool30002Ool4001dOol00`00Oomoo`0S

Ool00`00Oomoo`04000HOol01000Oomoo`001Woo00<007ooOol0@Woo001LOol4001]Ool00`00Oomo

o`0SOol01000Ool000006goo00@007ooOol000Ioo`03001oogoo049oo`00HWoo10000goo0P00Pgoo

00@007ooOomoo`<001eoo`04001oogoo0004Ool20015Ool006]oo`80009oo`8007eoo`@0021oo`04

001oogoo0004Ool00`00Oomoo`14Ool0075oo`<0009oo`@006]oo`05001oogooOol00002Ool3000T

Ool20006Ool20014Ool007eoo`@004aoo`03001oogoo01Eoo`04001oogooOol3001eOol008=oo`@0

00=oo`80045oo`03001oogoo01Eoo`@007Qoo`00S7oo0P000Woo0P00>goo00<007ooOol047oo00<0

07ooOol00`00Ngoo002BOol30002Ool4000bOol00`00Oomoo`0;Ool01000Oomoogoo10006Goo0P00

Hgoo002MOol5000iOol00`00Ool00002000KOol01000Oomoo`00HWoo002TOol40003Ool2000ZOol0

0`00Ool00003000NOol01000Oomoo`00HWoo002]Ool20002Ool2000JOol00`00Oomoo`07Ool4000P

Ool01000Oomoo`00HWoo002cOol30002Ool4000AOol20004Ool5000SOol01000Oomoo`00HWoo002n

Ool5000:Ool20002Ool4000VOol01000Oomoo`00HWoo0035Ool40004Ool5000ZOol2001SOol00<ao

o`<0099oo`00hgoo0P000goo1000MGoo003ROol01000Oomoo`001Woo00<007ooOol0LWoo003LOol4

0002Ool01000Oomoo`001Woo00<007ooOol0LWoo003ROol01000Oomoo`001Woo00<007ooOol0LWoo

003ROol01000Oomoo`0017oo0P00MGoo003ROol01000Oomoo`0017oo00<007ooOol0M7oo003SOol2

0006Ool2001dOol00?moof9oo`00d7oo0`00SWoo003AOol00`00Oomoo`2=Ool00<Uoo`@000Aoo`03

001oogoo08eoo`00dGoo00<007ooOol0SGoo003AOol00`00Oomoo`0VOol300000goo0000001QOol0

0=5oo`03001oogoo02Moo`04001oogoo001ROol00=1oo`8002Yoo`8006=oo`00o7oo0P00Hgoo003k

Ool01000Oomoo`00HWoo003kOol01000Oomoo`00HWoo003jOol300000goo0000001QOol00?moof9o

o`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003o

OomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9o

o`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003o

OomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9o

o`00ogooHWoo002QOol3002mOol00:9oo`03001oogoo0;aoo`00XWoo00<007ooOol0_7oo002JOol0

0`00Ool000020003Ool01000Ool000000Woo0`0000Aoo`000000009oo`<00004Ool000000004Ool3

002ROol009Yoo`8000=oo`03001oogoo0080009oo`04001oogoo0003Ool01000Oomoo`000goo00<0

07oo000017oo00D007ooOomoo`000:5oo`00VWoo00<007ooOol00Woo00@007ooOol000=oo`04001o

ogoo0003Ool01000Oomoo`001Goo00<007ooOol00Woo00<007ooOol0Xgoo002OOol01000Oomoo`00

0goo00@007ooOol000=oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`2SOol009eoo`80

00=oo`05001oogooOol00002Ool01@00Oomoogoo00000Woo1@0000=oo`00Ool00goo1@00XGoo002K

Ool20004Ool30002Ool00`00Oomoo`020002Ool01000Oomoo`000goo10000goo00D007ooOomoo`00

0:5oo`00VWoo00<007ooOol01Goo00@007oo000000=oo`04001oo`000004Ool30002Ool01000Ool0

00000Woo0`00XWoo002JOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2eOol009Yoo`04

001oogooOol20008Ool2002gOol009]oo`<00003Ool007oo00Qoo`03001oogoo0;Eoo`00\

\>"],

  ImageRangeCache->{{{0, 352}, {352, 0}} -> {-0.023892, -0.00314167, 

  0.00301379, 0.00301379}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["Plot the Magnetic Field", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The magnetic field created by the sphere is computed on the center and a \

profile along Y is plotted",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["\<\

RadPlotOptions[];

Print[\"Field in the Center = \",radFld[aSphere,\"b\",{0,0,0}]]

Plot[radFld[aSphere,\"Bx\",{0,y,0}],{y,-0.99,0.99}];\

\>", "Input",

  AspectRatioFixed->True],



Cell[BoxData[

    InterpretationBox[

      \("Field in the Center = "\[InvisibleSpace]{0.667282947541240734`, 

          4.21284210831316929`*^-10, 1.17398463997039903`*^-9}\),

      SequenceForm[ 

      "Field in the Center = ", {.66728294754124073, .42128421083131688*^-9,

         .1173984639970399*^-8}],

      Editable->False]], "Print"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

0.5 0.481001 0.196963 0.595442 [

[.019 -0.0125 -9.5 -15 ]

[.019 -0.0125 9.5 0 ]

[.2595 -0.0125 -14 -15 ]

[.2595 -0.0125 14 0 ]

[.5 -0.0125 -5 -15 ]

[.5 -0.0125 5 0 ]

[.7405 -0.0125 -9.5 -15 ]

[.7405 -0.0125 9.5 0 ]

[.981 -0.0125 -5 -15 ]

[.981 -0.0125 5 0 ]

[ 0 0 -0.125 0 ]

[-0.0125 .07787 -28 -7.5 ]

[-0.0125 .07787 0 7.5 ]

[-0.0125 .19696 -10 -7.5 ]

[-0.0125 .19696 0 7.5 ]

[-0.0125 .31605 -19 -7.5 ]

[-0.0125 .31605 0 7.5 ]

[-0.0125 .43514 -19 -7.5 ]

[-0.0125 .43514 0 7.5 ]

[-0.0125 .55423 -19 -7.5 ]

[-0.0125 .55423 0 7.5 ]

[ 0 0 -0.125 0 ]

[ 0 .61803 .125 0 ]

[ 1 0 .125 0 ]

[ -0.0005 -0.0005 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.2595 0 m

.2595 .61803 L

s

.5 0 m

.5 .61803 L

s

.7405 0 m

.7405 .61803 L

s

0 .07787 m

1 .07787 L

s

0 .19696 m

1 .19696 L

s

0 .31605 m

1 .31605 L

s

0 .43514 m

1 .43514 L

s

0 .55423 m

1 .55423 L

s

0 g

.019 0 m

.019 .00625 L

s

gsave

.019 -0.0125 -70.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.2595 0 m

.2595 .00625 L

s

gsave

.2595 -0.0125 -75 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.5 0 m

.5 .00625 L

s

gsave

.5 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.7405 0 m

.7405 .00625 L

s

gsave

.7405 -0.0125 -70.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.981 0 m

.981 .00625 L

s

gsave

.981 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.0671 0 m

.0671 .00375 L

s

.1152 0 m

.1152 .00375 L

s

.1633 0 m

.1633 .00375 L

s

.2114 0 m

.2114 .00375 L

s

.3076 0 m

.3076 .00375 L

s

.3557 0 m

.3557 .00375 L

s

.4038 0 m

.4038 .00375 L

s

.4519 0 m

.4519 .00375 L

s

.5481 0 m

.5481 .00375 L

s

.5962 0 m

.5962 .00375 L

s

.6443 0 m

.6443 .00375 L

s

.6924 0 m

.6924 .00375 L

s

.7886 0 m

.7886 .00375 L

s

.8367 0 m

.8367 .00375 L

s

.8848 0 m

.8848 .00375 L

s

.9329 0 m

.9329 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

0 .07787 m

.00625 .07787 L

s

gsave

-0.0125 .07787 -89 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .19696 m

.00625 .19696 L

s

gsave

-0.0125 .19696 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .31605 m

.00625 .31605 L

s

gsave

-0.0125 .31605 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .43514 m

.00625 .43514 L

s

gsave

-0.0125 .43514 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.4) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .55423 m

.00625 .55423 L

s

gsave

-0.0125 .55423 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.6) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .10765 m

.00375 .10765 L

s

0 .13742 m

.00375 .13742 L

s

0 .16719 m

.00375 .16719 L

s

0 .22673 m

.00375 .22673 L

s

0 .25651 m

.00375 .25651 L

s

0 .28628 m

.00375 .28628 L

s

0 .34582 m

.00375 .34582 L

s

0 .3756 m

.00375 .3756 L

s

0 .40537 m

.00375 .40537 L

s

0 .46491 m

.00375 .46491 L

s

0 .49468 m

.00375 .49468 L

s

0 .52446 m

.00375 .52446 L

s

0 .0481 m

.00375 .0481 L

s

0 .01833 m

.00375 .01833 L

s

0 .584 m

.00375 .584 L

s

0 .61377 m

.00375 .61377 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

.019 .61178 m

.019 .61803 L

s

.2595 .61178 m

.2595 .61803 L

s

.5 .61178 m

.5 .61803 L

s

.7405 .61178 m

.7405 .61803 L

s

.981 .61178 m

.981 .61803 L

s

.125 Mabswid

.0671 .61428 m

.0671 .61803 L

s

.1152 .61428 m

.1152 .61803 L

s

.1633 .61428 m

.1633 .61803 L

s

.2114 .61428 m

.2114 .61803 L

s

.3076 .61428 m

.3076 .61803 L

s

.3557 .61428 m

.3557 .61803 L

s

.4038 .61428 m

.4038 .61803 L

s

.4519 .61428 m

.4519 .61803 L

s

.5481 .61428 m

.5481 .61803 L

s

.5962 .61428 m

.5962 .61803 L

s

.6443 .61428 m

.6443 .61803 L

s

.6924 .61428 m

.6924 .61803 L

s

.7886 .61428 m

.7886 .61803 L

s

.8367 .61428 m

.8367 .61803 L

s

.8848 .61428 m

.8848 .61803 L

s

.9329 .61428 m

.9329 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

.99375 .07787 m

1 .07787 L

s

.99375 .19696 m

1 .19696 L

s

.99375 .31605 m

1 .31605 L

s

.99375 .43514 m

1 .43514 L

s

.99375 .55423 m

1 .55423 L

s

.125 Mabswid

.99625 .10765 m

1 .10765 L

s

.99625 .13742 m

1 .13742 L

s

.99625 .16719 m

1 .16719 L

s

.99625 .22673 m

1 .22673 L

s

.99625 .25651 m

1 .25651 L

s

.99625 .28628 m

1 .28628 L

s

.99625 .34582 m

1 .34582 L

s

.99625 .3756 m

1 .3756 L

s

.99625 .40537 m

1 .40537 L

s

.99625 .46491 m

1 .46491 L

s

.99625 .49468 m

1 .49468 L

s

.99625 .52446 m

1 .52446 L

s

.99625 .0481 m

1 .0481 L

s

.99625 .01833 m

1 .01833 L

s

.99625 .584 m

1 .584 L

s

.99625 .61377 m

1 .61377 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 .19696 m

1 .19696 L

s

.5 0 m

.5 .61803 L

s

.002 w

.02381 .01664 m

.02499 .01604 L

.02605 .01551 L

.02729 .01492 L

.02846 .60332 L

.02954 .60284 L

.03053 .60242 L

.03279 .60151 L

.03746 .59985 L

.04262 .59836 L

.04725 .59728 L

.05224 .59637 L

.05751 .59564 L

.06244 .59512 L

.06784 .59469 L

.07069 .59452 L

.07373 .59437 L

.07664 .59424 L

.07929 .59415 L

.08445 .59401 L

.08943 .59391 L

.09223 .59387 L

.09481 .59384 L

.09956 .5938 L

.10195 .59378 L

.10458 .59377 L

.10709 .59376 L

.10982 .59375 L

.11107 .59375 L

.1124 .59375 L

.11355 .59374 L

.11478 .59374 L

.11597 .59374 L

.11707 .59374 L

.11811 .59374 L

.11921 .59374 L

.12042 .59374 L

.12154 .59374 L

.12277 .59374 L

.12409 .59374 L

.12477 .59374 L

.1255 .59374 L

.12679 .59374 L

.12973 .59374 L

.13505 .59375 L

.145 .59376 L

.18289 .59384 L

.22323 .59393 L

.26206 .59401 L

.30333 .59409 L

Mistroke

.34309 .59416 L

.38134 .59421 L

.4027 .59424 L

.42204 .59426 L

.44222 .59427 L

.46122 .59428 L

.47101 .59429 L

.47635 .59429 L

.48134 .59429 L

.48559 .59429 L

.48778 .59429 L

.49015 .59429 L

.49275 .59429 L

.49395 .59429 L

.49521 .59429 L

.49635 .59429 L

.49761 .59429 L

.49875 .59429 L

.49982 .59429 L

.501 .59429 L

.50226 .59429 L

.50345 .59429 L

.50453 .59429 L

.5058 .59429 L

.50718 .59429 L

.50968 .59429 L

.5123 .59429 L

.51507 .59429 L

.52004 .59429 L

.52887 .59429 L

.53856 .59428 L

.54875 .59428 L

.55805 .59427 L

.57895 .59426 L

.61876 .59421 L

.65706 .59416 L

.69781 .59409 L

.73705 .59401 L

.77476 .59393 L

.81494 .59385 L

.83339 .59381 L

.84385 .59379 L

.85359 .59377 L

.85898 .59376 L

.86407 .59375 L

.86865 .59374 L

.87123 .59374 L

.87246 .59374 L

.87361 .59374 L

.87484 .59374 L

Mistroke

.87596 .59374 L

.87721 .59374 L

.8779 .59374 L

.87856 .59374 L

.87986 .59374 L

.88106 .59374 L

.88176 .59374 L

.88239 .59374 L

.8838 .59374 L

.8852 .59374 L

.8865 .59374 L

.88789 .59375 L

.88941 .59375 L

.89198 .59376 L

.8947 .59377 L

.89721 .59378 L

.89995 .5938 L

.90235 .59382 L

.90491 .59384 L

.90975 .5939 L

.91422 .59398 L

.91935 .59411 L

.92417 .59428 L

.92945 .59453 L

.93514 .59491 L

.94009 .59537 L

.9447 .59592 L

.94975 .59671 L

.95514 .59781 L

.96082 .59931 L

.96617 .60111 L

.96851 .60202 L

.96979 .60255 L

.97098 .60307 L

.97227 .01472 L

.97296 .01503 L

.97369 .01538 L

.97619 .01664 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol002Eoo`<003Ioo`<000=oo`03001oo`00008003Aoo`<0

03Ioo`<000=oo`03001oo`00008003Moo`<000Eoo`009Woo00<007ooOol0=7oo00D007ooOomoo`00

00Moo`03001oogoo031oo`05001oogooOol0000dOol01@00Oomoogoo00001goo00<007ooOol0=Goo

00<007ooOol017oo000VOol00`00Oomoo`0dOol01@00Oomoogoo000027oo00<007ooOol0;goo00D0

07ooOomoo`0003Aoo`05001oogooOol00008Ool00`00Oomoo`0dOol00`00Oomoo`04Ool001eoo`L0

009oo`03001oogoo02eoo`P000=oo`03001oogoo00Ioo`03001oogoo02moo`05001oogooOol0000d

Ool01@00Oomoogoo000027oo00<007ooOol0=7oo00<007ooOol017oo000VOol00`00Oomoo`0dOol0

1@00Oomoogoo000027oo00<007ooOol0;goo00D007ooOomoo`0003Aoo`05001oogooOol00008Ool0

0`00Oomoo`0dOol00`00Oomoo`04Ool002Ioo`03001oogoo03Aoo`05001oogooOol00007Ool00`00

Oomoo`0`Ool01@00Oomoogoo0000=7oo00D007ooOomoo`0000Moo`03001oogoo03Eoo`03001oogoo

00Aoo`009Woo00<007ooOol0=7oo00D007ooOomoo`0000Eoo`8003=oo`05001oogooOol0000dOol0

1@00Oomoogoo00001Goo0P00>7oo00<007ooOol017oo000UOol2000fOol01@00Oomoogoo00001Goo

00<007ooOol0<Woo00D007ooOomoo`0003Aoo`05001oogooOol00005Ool00`00Oomoo`0fOol20006

Ool002Ioo`03001oogoo03Eoo`<000Moo`<0039oo`<003Ioo`<000Moo`<003Ioo`03001oogoo00Ao

o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000OOooo00010001Ool001moo`03001oogoo

009oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo

00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo

00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo

00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo

00Yoo`05001oogooOol00001Ool001moo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo03]o

o`03001oogoo03Yoo`03001oogoo03]oo`05001oogooOol00001Ool001moo`03001oogoo03moo`03

00moogoo03]oo`03001oogoo03Yoo`0300moogoo03moo`40005oo`007goo00<007ooOol00goo0P00

>Woo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo0P001Goo0@000Goo000OOol20005

Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`03

Ool20001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yo

o`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo

00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol0

0`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol0

0`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03

001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<0

07ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@00

0Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?

Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`8000Eoo`03001oogoo03Qoo`0300moogoo03]o

o`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00=oo`80005oo`007goo00<007ooOol017oo

00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo

0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol0

0`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`03

00moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<0

07ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<0

07ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00

Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool000]oo`<000=oo`03001oo`0000@0

00Moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo

03Qoo`03001oogoo00Aoo`40005oo`002Woo00D007ooOomoo`0000Eoo`04001oogoo0007Ool00`00

Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00

Oomoo`04Ool10001Ool000Yoo`05001oogooOol00006Ool00`00Oomoo`07Ool2000500l00`0000l0

3`1f00l00`0000l03`1e00l00`0000l03`0300l20001Ool000=oo`P000=oo`03001oogoo00Eoo`03

001oogoo00Ioo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`03

00moogoo03Qoo`03001oogoo00Aoo`40005oo`002Woo00D007ooOomoo`0000Qoo`03001oogoo00Eo

o`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qo

o`03001oogoo00Aoo`40005oo`002Woo00D007ooOomoo`0000Qoo`03001oogoo00Eoo`03001oogoo

00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo

00Aoo`40005oo`002Woo00D007ooOomoo`0000Qoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o

ogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005o

o`002Woo00D007ooOomoo`0000Aoo`05001oogooOol00007Ool00`00Oomoo`04Ool00`00Oomoo`0h

Ool00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool000]o

o`<000Ioo`<000Qoo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yo

o`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo

00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol2

0005Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomo

o`03Ool20001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo

03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0

>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000O

Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0h

Ool00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]o

o`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo

00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo

0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol0

0`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`8000Eoo`03001oogoo03Qoo`0300moogoo

03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00=oo`80005oo`007goo00<007ooOol0

17oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol0

17oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0j

Ool00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qo

o`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo

00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo

00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol0

0`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03

001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40

005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<0

3gooOol0>7oo00<007ooOol017oo0@000Goo000OOol20005Ool00`00Oomoo`0hOol00`0?Oomoo`0k

Ool00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`03Ool20001Ool001moo`03001oogoo00Ao

o`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Ao

o`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo

00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol0

0`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03

001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03

001oogoo00Aoo`40005oo`005Goo0`001goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0

>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000DOol01@00Oomoogoo

00001Woo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03goo

Ool0>7oo00<007ooOol017oo0@000Goo000DOol01@00Oomoogoo00001Wooo`000@000Goo000DOol0

1@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0

>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000DOol01@00Oomoogoo00001Woo00<007oo

Ool017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007oo

Ool017oo0@000Goo000DOol01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol0>7oo00<0

3gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000DOol01@00

Oomoogoo00001Woo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo

00<03gooOol0>7oo00<007ooOol017oo0@000Goo000DOol01@00Oomoogoo00001Woo00<007ooOol0

17oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol0

17oo0@000Goo000EOol30007Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00

Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001o

ogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005o

o`007goo0P001Goo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo

00<007ooOol00goo0P000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol0

0`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03

001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40

005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<0

3gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?

Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001o

ogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001o

ogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007oo

Ool0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomo

o`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool0

01moo`8000Eoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03

001oogoo00=oo`80005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<0

07ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00

Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001

Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300mo

ogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03goo

Ool0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomo

o`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomo

o`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo

03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo0P001Goo00<007ooOol0>7oo00<0

3gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol00goo0P000Goo000OOol00`00

Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00

Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001o

ogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007oo

Ool0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo

000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomo

o`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo

03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`0037oo0`000goo00<0

07oo000010001Woo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo

00<03gooOol0>7oo00<007ooOol017oo0@000Goo000;Ool01@00Oomoogoo00001Goo00@007ooOol0

00Ioo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo

03Qoo`03001oogoo00Aoo`40005oo`002goo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`8000D0

3`0300003`0?07H03`0300003`0?07D03`0300003`0?00<03`80005oo`002goo00D007ooOomoo`00

00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo

03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`002goo00D007ooOomoo`0000Qoo`03001o

ogoo00Aoo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300mo

ogoo03Qoo`03001oogoo00Aoo`40005oo`002goo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03

001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03

001oogoo00Aoo`40005oo`002goo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo00Ao

o`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Ao

o`40005oo`002goo00D007ooOomoo`0000Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00

Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001

Ool000aoo`<000Ioo`<000Moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001o

ogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo0P001Goo00<007ooOol0>7oo

00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol00goo0P000Goo000OOol0

0`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol0

0`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03

001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<0

07ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@00

0Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?

Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300mo

ogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007oo

Ool017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007oo

Ool017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomo

o`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`8000Eoo`03001oogoo03Qoo`03

00moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00=oo`80005oo`007goo00<0

07ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<0

07ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00

Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001o

ogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005o

o`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03goo

Ool0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomo

o`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo

00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo

00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0

>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol20005Ool00`00Oomoo`0hOol00`0?

Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`03Ool20001Ool001moo`03001o

ogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001o

ogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007oo

Ool0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomo

o`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool0

01moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo

03Qoo`03001oogoo00Aoo`40005oo`0037oo0`000goo00<007ooOol00goo00<007ooOol017oo00<0

07ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<0

07ooOol017oo0@000Goo000;Ool01@00Oomoogoo000027oo00<007ooOol017oo00<007ooOol017oo

00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo

0@000Goo000;Ool01@00Oomoogoo000017oo1P001Goo0P001@0?00<0000?00l0MP0?00<0000?00l0

M@0?00<0000?00l00`0?0P000Goo000;Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ioo`03

001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03

001oogoo00Aoo`40005oo`002goo00D007ooOomoo`0000Eoo`04001oogoo0006Ool00`00Oomoo`04

Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04

Ool10001Ool000]oo`05001oogooOol00006Ool00`00Ool00006Ool00`00Oomoo`04Ool00`00Oomo

o`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool0

00]oo`05001oogooOol00006Ool00`00Ool00006Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?

Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool000]oo`05001o

ogooOol00007Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomo

o`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool000aoo`<000Uoo`03001oogoo00Aoo`03

001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03

001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<0

07ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol20005Ool00`00Oomoo`0h

Ool00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`03Ool20001Ool001mo

o`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qo

o`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo

00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool0

0`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool1

0001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`03

00moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007ooOol0>7oo00<0

3gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000OOol00`00

Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00

Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03001o

ogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo0P001Goo00<007ooOol0>7oo

00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol00goo0P000Goo000OOol0

0`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol0

0`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300moogoo03]oo`03

001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<0

07ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@00

0Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?

Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`0300mo

ogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<007oo

Ool017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007oo

Ool017oo0@000Goo000OOol20005Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol0

0`0?Oomoo`0hOol00`00Oomoo`03Ool20001Ool001moo`03001oogoo00Aoo`03001oogoo03Qoo`03

00moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005oo`007goo00<0

07ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<0

07ooOol017oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00

Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001o

ogoo03Qoo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00Aoo`40005o

o`007goo00<007ooOol017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03goo

Ool0>7oo00<007ooOol017oo0@000Goo000<Ool30003Ool00`00Oomoo`030007Ool00`00Oomoo`04

Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0hOol00`00Oomoo`04

Ool10001Ool000]oo`05001oogooOol00004Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<0

07ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@00

0Goo000;Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ioo`8000D03`0300003`0?07H03`03

00003`0?07D03`0300003`0?00<03`80005oo`002goo00D007ooOomoo`0000Aoo`05001oogooOol0

0006Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomo

o`0hOol00`00Oomoo`04Ool10001Ool000]oo`05001oogooOol00004Ool20002Ool00`00Oomoo`04

Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0h

Ool00`00Oomoo`04Ool10001Ool000]oo`05001oogooOol00004Ool01000Ool000001goo00<007oo

Ool017oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007oo

Ool017oo0@000Goo000;Ool01@00Oomoogoo00001Goo00<007ooOol01goo00<007ooOol017oo00<0

07ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@00

0Goo000;Ool01@00Oomoogoo00001Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0>7oo

00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol017oo0@000Goo000<Ool3

0008Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0jOol0

0`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`8000Eoo`03001oogoo03Qoo`0300moogoo

03]oo`03001oogoo03Yoo`0300moogoo03Qoo`03001oogoo00=oo`80005oo`007goo00<007ooOol0

17oo00<007ooOol0>7oo00<03gooOol0>goo00<007ooOol0>Woo00<03gooOol0>7oo00<007ooOol0

17oo0@000Goo000OOol00`00Oomoo`04Ool00`00Oomoo`0hOol00`0?Oomoo`0kOol00`00Oomoo`0j

Ool00`0?Oomoo`0hOol00`00Oomoo`04Ool10001Ool001moo`03001oogoo00Aoo`03001oogoo00Ao

on@000Ioo`03001oogoo00Aoo`40005oo`007goo00<007ooOol017oo00<007oo00001000=7oo00<0

3gooOol0>goo00<007ooOol0>Woo00<03gooOol0<Woo10000Woo00<007ooOol017oo0@000Goo000O

Ool00`00Oomoo`04Ool2000iOol00`0?Oomoo`0kOol00`00Oomoo`0jOol00`0?Oomoo`0fOol30006

Ool10001Ool001moo`03001oogoo03moo`0300moogoo03]oo`03001oogoo03Yoo`0300moogoo03mo

o`40005oo`007goo00<007ooOol00Woo00<007ooOol0>Woo00<007ooOol0>goo00<007ooOol0>Woo

00<007ooOol0>goo00D007ooOomoo`00005oo`007goo0P000goo00<007ooOol02Goo00<007ooOol0

2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0

2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0

2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0

2Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol00P000Goo000OOooo

00010001Ool00001\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.29319, -0.452312, 

  0.00813191, 0.006569}}]

}, Open  ]]

}, Open  ]]

},

FrontEndVersion->"Microsoft Windows 3.0",

ScreenRectangle->{{0, 1280}, {0, 968}},

WindowToolbars->{},

CellGrouping->Manual,

WindowSize->{608, 631},

WindowMargins->{{61, Automatic}, {Automatic, 24}},

PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},

ShowCellLabel->False,

ShowCellTags->False,

RenderingOptions->{"ObjectDithering"->True,

"RasterDithering"->False},

CharacterEncoding->"MacintoshAutomaticEncoding",

StyleDefinitions -> "Classroom.nb"

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{

Cell[1709, 49, 147, 3, 43, "Title"],

Cell[1859, 54, 77, 2, 29, "Text"],



Cell[CellGroupData[{

Cell[1961, 60, 79, 2, 56, "Section"],

Cell[2043, 64, 2375, 58, 331, "Text"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4455, 127, 102, 2, 56, "Section"],

Cell[4560, 131, 222, 6, 29, "Text"],

Cell[4785, 139, 52, 1, 50, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4874, 145, 85, 2, 56, "Section"],

Cell[4962, 149, 273, 6, 48, "Text"],

Cell[5238, 157, 938, 14, 410, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[6213, 176, 105, 2, 56, "Section"],

Cell[6321, 180, 781, 19, 105, "Text"],

Cell[7105, 201, 66, 1, 50, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[7208, 207, 94, 2, 56, "Section"],

Cell[7305, 211, 198, 5, 29, "Text"],



Cell[CellGroupData[{

Cell[7528, 220, 219, 9, 158, "Input"],

Cell[7750, 231, 90667, 3155, 361, 52723, 2681, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[98466, 3392, 90, 2, 56, "Section"],

Cell[98559, 3396, 234, 6, 29, "Text"],



Cell[CellGroupData[{

Cell[98818, 3406, 185, 5, 86, "Input"],

Cell[99006, 3413, 342, 7, 25, "Print"],

Cell[99351, 3422, 32284, 965, 186, 11694, 706, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



